package PAR::StrippedPARL::Dynamic;
use 5.008001;
use strict;
use warnings;
our $VERSION = '0.958';

use base 'PAR::StrippedPARL::Base';

our $Data_Pos = tell DATA;

=head1 NAME

PAR::StrippedPARL::Dynamic - Data package containing a dynamic PARL

=head1 SYNOPSIS

  # For details, see PAR::StrippedPARL::Base.
  PAR::StrippedPARL::Dynamic->write_parl($file) or die "Some error...";

=head1 DESCRIPTION

This class is internal to PAR. Do not use it outside of PAR.

This class is basically just a container for a dynamic binary PAR loader
which doesn't include the PAR code like the F<parl> or F<parl.exe>
you are used to. If you're really curious, I'll tell you it is
just a copy of the F<myldr/par> (or F<myldr/par.exe>) file.

The data is appended during the C<make> phase of the PAR build process,
but only if applicable: If you perl is static, you won't get the dynamic
loader.

If the binary data isn't appended during the build process, the class
methods will return the empty list.

=head1 CLASS METHODS

Inherits the methods from L<PAR::StrippedPARL::Base>.

=cut

sub _data_pos {
    my $class = shift;
    return $Data_Pos;
}

=head1 AUTHORS

Steffen Mueller E<lt>smueller@cpan.orgE<gt>,
Audrey Tang E<lt>cpan@audreyt.orgE<gt>

=head1 COPYRIGHT AND LICENSE

Copyright 2006-2009 by Steffen Mueller E<lt>smueller@cpan.orgE<gt>.

This program is free software; you can redistribute it and/or 
modify it under the same terms as Perl itself.

See F<LICENSE>.

=cut

$^V eq 5.28.1 
    or die sprintf("Perl (%s) version (%vd) doesn't match the version (5.28.1) ".
                   "that PAR::Packer was built with; please rebuild PAR::Packer", 
                   $^X, $^V);

1;

__DATA__
M?T5,1@(!`0````````````,`"``!````0!X```````!``````````/BW````
M````!P``@$``.``*`$``'@`=``8````$````0`````````!``````````$``
M````````,`(````````P`@````````@``````````P````0```"0I```````
M`)"D````````D*0````````/``````````\``````````0`````````#``!P
M!````'`"````````<`(```````!P`@```````!@`````````&``````````(
M``````````$````%````````````````````````````````````Q*0`````
M``#$I````````````0```````0````8```#PKP```````/"O`0``````\*\!
M``````"``P```````,`3```````````!```````"````!````$`$````````
M0`0```````!`!````````*`"````````H`(````````(``````````0````$
M````&`0````````8!````````!@$````````)``````````D``````````0`
M````````!`````0```"DI````````*2D````````I*0````````@````````
M`"``````````!`````````!2Y71D!````/"O````````\*\!``````#PKP$`
M`````!``````````$``````````!````````````````````````````````
M``````````````````````````````````````````@```````````!``@("
M``$```````````$``````````2@```````#V!P"R````````````````````
M```````P,`(```````$H````````````````````````````````````````
M,#`"```````!*````````````````````````````````````````#`P`@``
M`````2@````````$``"R```````````````````````````P,`(```````$H
M````````/``!L@``````````````````````````,#`"```````!*```````
M`/S___,``````````````````````````#`P`@```````2@```````"$``"R
M```````````````````````````P,`(```````$H````````<``_L@``````
M````````````````````,#`"```````!*```````````````````````````
M`````````````#`P`@```````2@```````````"P````````````````````
M```````P,`(```````0````4`````P```$=.50#LM?;PB_%LK2@PDYB$-+C-
MR->I6@`````!`````````!P``````````0````````#7`0````````$`````
M````X@$````````!`````````.P!`````````0`````````[`@````````$`
M````````G0,````````!`````````+<#````````#`````````!0&P``````
M``T`````````$&0````````9`````````/"O`0``````&P`````````(````
M`````!H`````````^*\!```````<``````````@`````````!`````````#@
M!@````````4`````````0!0````````&`````````"`*````````"@``````
M```R!0````````L`````````&``````````U``!P`````-"J`0``````%0``
M``````````````````,`````````0+`!```````1```````````;````````
M$@````````!0`````````!,`````````$``````````!``!P``````$`````
M````!0``<``````"``````````8``'`````````````````*``!P`````!P`
M````````$0``<`````!L`````````!(``'``````'0`````````3``!P````
M`",`````````'@`````````(`````````/O__V\``````0``"`````#^__]O
M`````%`:````````____;P`````#`````````/#__V\`````<AD`````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``````!A````;````````````````````"L``````````````#(`````````
M`````"@```!-`````````$<```!.````#@````````!6````&0````,````M
M````"0```!$````]````,```````````````5P```!4````G````````````
M```B````'````#X``````````````!8````A`````````#8`````````-```
M``````!H````%````!(````E`````````&D````:`````````$8```!4````
M```````````8````2````#H```!%``````````````!?`````````%$`````
M````(```````````````8P```"8````I````+@```$0````J````````````
M```"````"P```$````!F````&P```!`````U`````````",````?````````
M```````3````%P`````````_````'@```$(````D````,0```#L`````````
M````````````````````````````````90```````````````````&<`````
M``````````````!0````9`````H````-``````````````!#````!```````
M``````````````````!=````60````````````````````````!<````-P``
M`#P`````````,P```$H````O````'0`````````L``````````````!>````
M:P```&(```!/````.0```$$```!)`````````#@```!2``````````````!A
M````3`````````````````````\`````````"```````````````8`````P`
M``!+``````````````!:``````````````!8````````````````````````
M`%,```!5````````````````````````````````````6P```&H`````````
M``````4````````````````````'```````````````````````````````&
M````````````````````````````````````````````````````````````
M``````````````,`"P!0&P``````````````````U0,``!(`#``H8```````
M``@`````````G00``!(`#`!00@```````!@``````````0```!,`\?\!````
M````````````````Q`0``"$`%0``L`$`````````````````DP,``!$`````
M````````````````````&00``!(`#``@2@```````%@`````````D00``!(`
M#`!P7@```````,0`````````K@0``!``&`!PLP$`````````````````WP,`
M`!(`#@`09```````````````````M00``!(`#`#X1````````"P`````````
M>P0``!(`#``H10```````+0!````````;@0``!(`#`#(2P```````*@-````
M````P@0``!$`%0``L`$`````````````````=0,``!$`#P!`9`````````0`
M````````SP0``!``%0``L`$``````````````````P0``!(`#`!000``````
M`/P`````````$@```!$`%@`PL`$`````````````````Q0,``!(`#`"`7P``
M`````*@`````````AP0``!$`%0`@L`$```````@`````````U@0``!``&0"P
MPP$`````````````````800``!(`#`#@1@```````(@"````````VP0``!``
M&0!PLP$`````````````````Y0,``!(`#`!X0````````%@`````````QP(`
M`!(`#`"0&P```````*@"````````YP0``!(`#`!`'@``````````````````
M-`0``!(`#`!H0@```````(P"````````3P0``!(`#`!X2@```````$P!````
M````E`,``"$`````````````````````````000``!(`#`!H20```````+@`
M````````[P0``!``#`"0&P``````````````````]@0``!``&0!PLP$`````
M````````````YP,``!(`"P!0&P``````````````````[0,``!(`#`!P60``
M```````%````````'@,``!(```#P8P``````````````````10(``!(```#@
M8P``````````````````G`(``!(```#08P``````````````````_`$``!(`
M``#`8P``````````````````:@,``!(```"P8P```````````````````@(`
M`!(```"@8P``````````````````Z0(``!(```"08P``````````````````
ME0,``!$`````````````````````````E`(``!(```"`8P``````````````
M````PP```"``````````````````````````6P(``!(```!P8P``````````
M````````.@,``!(```!@8P``````````````````N@```!(```!08P``````
M````````````W0```!(```!`8P``````````````````J0```!(`````````
M````````````````[````!(````P8P``````````````````,P,``!(````@
M8P``````````````````:0(``!(````08P``````````````````^@```!(`
M````8P``````````````````G@```!(```#P8@``````````````````30(`
M`!(```#@8@``````````````````"P$``!(```#08@``````````````````
MD````!(```#`8@``````````````````+`,``!(```"P8@``````````````
M````*@(``!(```"@8@``````````````````?0```!(`````````````````
M````````"P,``!(```"08@``````````````````?@(``!(```"`8@``````
M````````````%P$``!(```!P8@``````````````````(@$``!(```!@8@``
M````````````````-P$``!(```!08@``````````````````%@(``!(```!`
M8@``````````````````N@(``!(````P8@``````````````````2P,``!(`
M```@8@``````````````````;@```!(````08@``````````````````LP(`
M`!(`````8@``````````````````Y`(``!(```#P80``````````````````
M0P$``"(`````````````````````````$0,``!(```#@80``````````````
M````4@$``!(```#080``````````````````;@$``!(```#`80``````````
M````````A`,``!(```"P80``````````````````8@$``!(```"@80``````
M````````````<`(``!(```"080``````````````````(@(``!(```"`80``
M````````````````^0(``!(```!P80``````````````````8P```!(```!@
M80``````````````````=0$``!(```!080``````````````````AP$``!(`
M``!`80``````````````````S`(``!(````P80``````````````````E0$`
M`!$`````````````````````````50```!(````@80``````````````````
MA0(``!(````080``````````````````H@$``!$`````````````````````
M````8P,``!(`````80``````````````````4@,``!(```#P8```````````
M````````2P```!(```#@8```````````````````/````!(```#08```````
M````````````\P(``!(```#`8```````````````````+````!(`````````
M````````````````K0$``!(```"P8```````````````````I0,``!$`````
M````````````````````1`,``!(```"@8```````````````````I0(``!(`
M``"08```````````````````4````!(```"`8```````````````````C`(`
M`!(```!P8```````````````````C`,``!$`````````````````````````
M*P0``!(```!@8```````````````````NP$``"``````````````````````
M````'0(``!(```!08```````````````````U0(``"(`````````````````
M````````=P(``!(```!`8```````````````````K`(``!(````P8```````
M`````````````%]$64Y!34E#7TQ)3DM)3D<`7U]23$1?34%0`&QI8G!E<FPN
M<V\N-2XR.`!B;V]T7T1Y;F%,;V%D97(`<&5R;%]C;VYS=')U8W0`<&5R;%]F
M<F5E`'!E<FQ?9&5S=')U8W0`<&5R;%]A;&QO8P!097)L7W-Y<U]I;FET,P!0
M97)L7V%T9F]R:U]U;FQO8VL`4&5R;%]S>7-?=&5R;0!P97)L7W!A<G-E`%!E
M<FQ?871F;W)K7VQO8VL`<&5R;%]R=6X`7TE435]R96=I<W1E<E1-0VQO;F54
M86)L90!097)L7W-V7W-E='!V;@!097)L7V%V7V9E=&-H`%!E<FQ?;F5W6%-?
M9FQA9W,`4&5R;%]M9U]S970`4&5R;%]N97=84P!097)L7V-R;V%K7VYO8V]N
M=&5X=`!097)L7V=E=%]S=@!?7V=M;VY?<W1A<G1?7P!097)L7V=V7V9E=&-H
M<'8`4&5R;%]S869E<WES;6%L;&]C`%!E<FQ?<W9?,G!V7V9L86=S`%!E<FQ?
M<W9?<V5T<'8`4$Q?9&]?=6YD=6UP`%!,7W1H<E]K97D`4&5R;%]A=E]S:&EF
M=`!?251-7V1E<F5G:7-T97)434-L;VYE5&%B;&4`;&EB9&PN<V\N,@!L:6)M
M+G-O+C8`;&EB<'1H<F5A9"YS;RXP`&-L;W-E`'!T:')E861?9V5T<W!E8VEF
M:6,`;W!E;C8T`')E860`;'-E96LV-`!?7V5R<FYO7VQO8V%T:6]N`&QI8F,N
M<V\N-@!O<&5N9&ER`%]?<W1R;F-P>5]C:&L`7U]F<')I;G1F7V-H:P!A8V-E
M<W,`9V5T<&ED`'-T<F-M<`!M96US970`=6YL:6YK`&UE;6UO=F4`<W1R;F-M
M<`!C;&]S961I<@!S=')D=7``<W1R<W1R`'-T<F-H<@!?7VQI8F-?<W1A<G1?
M;6%I;@!R96%D;&EN:P!?7V-X85]F:6YA;&EZ90!E>&ET`%]?>'-T870V-`!R
M;61I<@!?7W)E9VES=&5R7V%T9F]R:P!M:V1I<@!?7VUE;6-P>5]C:&L`7U]S
M<')I;G1F7V-H:P!M96UC:'(`<W1R=&]K`')E861D:7(V-`!M96UC<'D`<W1R
M;&5N`%]?<W1A8VM?8VAK7V9A:6P`9V5T=6ED`%]?;'AS=&%T-C0`7TE/7W-T
M9&EN7W5S960`<F5A;&QO8P!S=&1E<G(`7U]E;G9I<F]N`&QD+G-O+C$`7U]S
M=&%C:U]C:&M?9W5A<F0`;&EB8W)Y<'0N<V\N,0!?7VQI8F-?8W-U7VEN:70`
M7U]L:6)C7V-S=5]F:6YI`'AS7VEN:70`6%-?26YT97)N86QS7U!!4E]"3T]4
M`'!A<E]C=7)R96YT7V5X96-?<')O8P!G971?=7-E<FYA;65?9G)O;5]G971P
M=W5I9`!P87)?9FEN9'!R;V<`<&%R7V5N=E]C;&5A;@!P87)?<V5T=7!?;&EB
M<&%T:`!P87)?:6YI=%]E;G8`<&%R7VUK=&UP9&ER`'!A<E]D:7)N86UE`&UY
M7W!A<E]P;`!P87)?8VQE86YU<`!P87)?8W5R<F5N=%]E>&5C`%]E9&%T80!P
M87)?8F%S96YA;64`7U]D871A7W-T87)T`%]F9&%T80!?96YD`%]?8G-S7W-T
M87)T`%]?<W1A<G0`7V9T97AT`%]F8G-S`$=,24)#7S(N-`!'3$E"0U\R+C(`
M1TQ)0D-?,BXP`$=,24)#7S(N,RXT`$=,24)#7S(N,RXR```````!``$``0`!
M``(``0`!``$``0`!``$``0`!``$``0`!``$``0`!``$``0`!``$``0`!``$`
M`0`"``$``0`!``$``0`)``(``@`$``,`!``#``(``@````D``P``````````
M``(``@``````"0```````@`$`````@`"``````````@``@`"`````@`"````
M"0````(``@````(`"``'``````````(```````(````"``8```````(`````
M``4``@`"``(``@`"``(````$``,``@`"``````````$``0"=`P``$````"``
M```4:6D-```%`/P$`````````0`"`.P!```0````,````!)I:0T```@`!@4`
M`!`````0:6D-```$`!`%`````````0`%`#L"```0`````````'09:0D```D`
M&@4``!````!R&6D)```'`"8%```0````%&EI#0``!@#\!```$````!)I:0T`
M``,`!@4``!`````0:6D-```"`!`%`````````````````````````````/"O
M`0``````````````$@/XKP$``````````````!(#(+`!```````````````2
M`VBS`0``````````````$@/P_[UG``"\_P(`'#PMX)D#"`"__^`4G&<8@H+?
M!`!`$``````8@IG?"?@@`P`````(`+_?``"\WP@`X`,0`+UGD/^]9V``O/\"
M`!P\+>"9`Z`4G&<X`+'_V(*1WV@`O_\`@IG?6`"U_U``M/](`+/_0`"R_S``
ML/\``"+>$`"E_P@`IO\<`*2O"`"F9Q``I6<<`*1G*`"B_PGX(`,`````N(&&
MWV"!A-^P@)G?T!`1!"4HP`"`@H+?``!"D&$`0!!@@IG?.("0WYB"DM\8@9G?
M"?@@`P``1(X``$2.Z@1#D!B!F=\"`&,T"?@@`^H$0Z`<`*2/Z@1#D`4`A"1`
M@IG?`0!C-/@@!``)^"`#Z@1#H!``I=^X@(3?``"CW```A]P``$/\4("#WQP`
MIH\(:&-D"`!#_%"`@]\X@(C?$&AC9!@`0_PX@(/?$`!'_`(`Q"@$``<D!`#)
M)(C#`OT+`(`4D,-GK`@`I60E."`!!0`#)```J-SX(`,`+2!$``$`8R3X_XC\
M^O_C%`@`I610@(7?B(&9W_A("0"@PP3>+4A)`"5````E.$```P#&)-!`I60)
M^"`#^/\@_2\`0!`EF$``B(*9WZ##!-Y0@)+?"?@@`R0`M&=0@(3?V#929B4H
M@`(ER$`":`81!#AEA&0G`$`0.("5W[""F=\)^"`#H,,$WJ"!F=\)^"`#````
M`"@`I-\``"/>+@"#%"408`)H`+_?8`"\WU@`M=]0`+3?2`"SWT``LM\X`+'?
M,`"PWP@`X`-P`+UG"?@@`SB`D-\C`$`0H,,"_KB"F=\E($``"?@@`YB"DM\8
M@9G?"?@@`P``1(Z6_P`0@0I`H%"!F=\)^"`#H,,$WL[_`!`EF$``F,.DW@4`
M@!#`@)G?(1`1!`````#5_P`0L(*9WU"`A-\E*(`")<A``C0&$03`9(1D)2!`
M`,S_0!"8PZ+^\_\`$,"`F=^H@IG?"?@@`P`````0@IG?"?@@`P$`!"0`````
M`````"4`X`,!`!$$`````"7(@`,"`!P\Y!&<)RW@GP,E^```(("$WP``I=\(
M`*9G\/\!)"3HH0,H@(??,("(WR5(0``E4*`#\(&9WPGX(`,`````__\`$```
M``````````````(``SPM&'D`D!%C9#B`9-Q`@&+<.+"$9`4`1!`0@WG<`P`@
M$P`````(`"`#``````@`X`,``````@`#/"T8>0!8$6-D.(!DW$"`9=PXL(1D
M+RBD`/LH!0#^%P4`+2A%`'LH!0`%`*`0.(%YW`,`(!,`````"``@`P`````(
M`.`#``````````#@_[UG$`"\_P(`'#PMX)D#"!&<9P@`L/\X@)#?&`"__W"S
M`I(,`$`4((."WP0`0!!(@(+?((.9WPGX(`,``$3<4("9WZ`>.6?+_Q$$````
M``$``B1PLP*B&`"_WQ``O-\(`+#?"`#@`R``O6<``````@`"/"T060"8$$)D
M4(!9W-@>.6?*_P`0`````````````````````$#]O6>P`KS_`@`</"W@F0-P
M$)QGV(*)W[@"O_^H`K/_H`*R_Y@"L?^0`K#_```BW0@`HV>(`J+_.`"(9'@`
MC60E4&``_P`,/```!]T```6-/C`'`#X2!P`X7@8`/CX'``#_0C`E$$<`H"@%
M?`/X9WTX,@8``BPE`"401P`D,,P``_BE?"401@`(``AE``!%_0@`0OWL_Z@5
M$`!*90`":&1H`&+<0`!GW!``9MP``&7<)A!'`"801@`F$$4`>"@"`/H7`@`E
M$*(``_A"?(``8OP(`&-D\O]H%!``K]\``(O<$`"'W!@`B-P(`*W?@EH,/)EY
MC&4(`(;<(`"*W/H>"P!X$0L`)1!#`"UHK`$F&.@`N'<&`"UHJ@$D&&8`NB@&
M``/X0GPE*,4!)AAH`"T030`M$$,``_BM?`/X0GPF&.T`^L8"`"08:P`M>.P!
M>'$"`"UXZ`$F&&<`)7#8`2T8;P"XQPL``_C.?;IX"P`E>`\#+1AN`!@`KM\#
M^&-\)BBO`/K.`P`D**(`+7#,`7C!`P`M<,<!)BBM`"7`&0,M**X``_@8?[AW
M`@"Z$`(`)7#"`2``N=\M$+@``_A"?"8H[@%XP0(`^H8"``/X[WTD**,`+<@L
M`RW(+0,F**\`)6@0`RTHN0`#^*U]N,<#`+H8`P`EP`,#*`"YWRT8K0`#^&U\
M)AC8`2W(+`/ZA@T``_C.?2088@!X*0T`+7@O`R88;@`E*+``+1AO``/XI7RX
M?P(`NA`"`"5XX@$M$&4`,`"CWP/X17PF$`\#+1AL``/X&'_ZA@4`)!!-`'C)
M!0`M<&X`)A!8`"7(,`.Z&`T`+1!.``/X.7^X=PT`)7##`2T060`X`+G?`_A#
M?"80[@%X:0,`^H8#``/X[WTD$$4`+<@L`RW(.`,F$$\`)<"P`2T060`#^!A_
MN&\%`+HH!0`E:*4!+1!8`$``N=\#^$5\)A#-`2W(+`/ZA@4``_C.?2000P!X
MP04`+7@O`R803@`EP!`#+1!/``/X&'^X?P,`NA@#`"5XXP$M$%@`2`"YWP/X
M0WPF$*\!+<@L`_J&`P`#^*U])!!%`'C!`P`M<"X#)A!-`"7`$`,M$$X``_@8
M?[AW!0"Z*`4`)7#%`2T06`!0`+G?`_A%?"80[@$MR"P#^H8%``/X[WTD$$,`
M>,$%`"UH+0,F$$\`)<`0`RT030`#^!A_N&\#`+H8`P`E:*,!+1!8`%@`N=\#
M^$-\)A#-`2W(+`/ZA@,``_C.?20010!XP0,`+7@O`R803@`EP!`#+1!/``/X
M&'^X?P4`NB@%`"5XY0$M$%@`8`"YWP/X17PF$*\!+<@L`_J&!0`#^*U])!!#
M`'C!!0`M<"X#)A!-`"7`$`,M$$X``_@8?[AW`P"Z&`,`)7##`2T06`!H`+G?
M`_A#?"80[@$MR"P#^H8#``/X[WTD$$4`>,$#`"UH+0,F$$\`)<`0`RT030`#
M^!A_N&\%`+HH!0`E:*4!+1!8`'``N=\#^$5\)A#-`2W(+`/ZA@4``_C.?200
M0P!XP04`+7@O`R803@`EP!`#+1!/``/X&'^X?P,`NA@#`"5XXP$M$%@`>`"Y
MWP/X0WPF$*\!+<@L`_J&`P`#^*U])!!%`'C!`P`M<"X#)A!-`"7`$`,M$$X`
M`_@8?[AW!0"Z*`4`)7#%`2T06`"``+G?`_A%?"80[@$MR"P#`_CO??J&!0`D
M$$,`>,$%`"UH+0,F$$\`)<`0`RT030`#^!A_N&\#`+H8`P`E:*,!+1!8`(@`
MN=\#^$-\)A#-`7C!`P`#^,Y]^H8#`"0010`MR"P#+<@O`R803@`E>!`#+1!9
M``/X[WVXSP4`NB@%`"7()0,M$$\`D`"XWP/X17PF$+D!>'D%``/XK7WZA@4`
M)!!#`"W`#`,MP`X#)A!-`"5P\`$M$%@``_C.?;C'`P"Z&`,`)<`#`RT03@"8
M`*_?`_A"?"88.`-X<0(`^H8"``/X.7\D&&4`+7CL`2UX[0$F&'D`)6C0`2T8
M;P"X=P4``_BM?;HH!0`E<,4!+6AM`*``I=\#^*]])A@.`RTHK`#ZA@\``_@8
M?R088@!X80\`+<BY`"88>``E8)`!+1AY``/XC'TM8&P`N,\"`-EN`SRZ$`(`
MH>ME-"7((@.H`*/?`_B0?280V0$M&&4`^HX0`"8030!X:1``+<!X`"5HL0$#
M^$)\+1!8``/XK7VXQP\`NG@/`"UH30`EP`\#L`"BWP/XHWTF>#@#`_C1?2T0
M10`F<.P!^GX#`'AA`P`M$%$``_C.?25@CP$M$$X`N'\0``/XC'VZ@!``)7CP
M`2U@3`"X`*+?`_B0?29P#P/ZCA``+1!%``/X.7\F<,T!>&D0`"T060`#^,Y]
M)6BQ`2T03@`#^*U]N'<#`+H8`P`E<,,!+1A-`,``HM\#^'E\)FCN`?J.&0`M
M$$4``_@8?R9HK`%X81D`+1!8``/XK7TE8)$!+1!-``/XC'VX;Q``NH`0`"5H
ML`$M8$P`R`"BWP/XF'TF@,T!`_CQ?2T010`F>`,"^H88`'@9&``M$%$``_CO
M?248<``M$$\``_AC?+A_&0"ZR!D`)7CY`2T80P#0`*+?`_AY?":`KP$#^-%]
M+1!%`"9P#`+ZAAD`>&$9`"T040`#^,Y])6"0`2T03@`#^(Q]N'<8`+K`&``E
M<-@!+6!,`-@`HM\#^)A])H#N`0/XL7TM$$4`)F@#`OJ&&`!X&1@`+1!1``/X
MK7TE&'``+1!-``/X8WRX;QD`NL@9`"5HN0$M&$,`X`"BWP/X>7PF@,T!`_CQ
M?2T010`F>`P"^H89`'AA&0`M$%$``_CO?25@D`$M$$\``_B,?;A_&`"ZP!@`
M)7CX`2U@3`#H`*+?`_B8?2:`KP$#^-%]+1!%`"9P`P+ZAA@`>!D8`"T040`#
M^,Y])1AP`"T03@`#^&-\N'<9`+K(&0`E<-D!+1A#`/``HM\#^'E\)H#N`0/X
ML7TM$$4`)F@,`OJ&&0!X81D`+1!1``/XK7TE8)`!+1!-``/XC'VX;Q@`NL`8
M`"5HN`$M8$P`^`"BWP/XF'TF@,T!`_CQ?2T010`F>`,"^H88`'@9&``M$%$`
M`_CO?248<``M$$\``_AC?+A_&0"ZR!D`)7CY`2T80P```:+?`_AY?":`KP$#
M^-%]+1!%`"9P#`+ZAAD`>&$9`"T040`#^,Y])6"0`2T03@`#^(Q]N'<8`+K`
M&``E<-@!+6!,``@!HM\#^)A])H#N`0/XL7TM$$4`)F@#`OJ&&`!X&1@`+1!1
M``/XK7TE&'``+1!-``/X8WRX;QD`NL@9`"5HN0$M&$,`$`&BWP/X>7PF@,T!
M`_CQ?2T010`F>`P"^H89`'AA&0`M$%$``_CO?25@D`$M$$\``_B,?;A_&`"Z
MP!@`)7CX`2U@3``8`:+?`_B8?2:`KP$#^-%]+1!%`"9P`P+ZAA@`>!D8`"T0
M40`#^,Y])1AP`"T03@`#^&-\N'<9`+K(&0`E<-D!+1A#`"`!HM\#^'!\)LCN
M`0/XL7TM$$4`)F@L`_K.$`!X81``+1!1``/XK7TE8)D!+1!-``/XC'VX;Q@`
MNL`8`"5HN`$M8$P`*`&BWP/XF7TFP,T!`_CQ?2T010`F>`,#^L89`'@9&0`M
M$%$``_CO?248>``M$$\`N,<0``/X8WRZ@!``)<`0`RT80P`P`:+?`_AP?"9X
MN`$#^-%]+1!%`"9@[`%X<1``^GX0`"T040`#^(Q])7#/`2T03`"X?QD``_C.
M?;K(&0`E>/D!+7!.`#@!HM\#^-E])F`/`_J.&0`M$$4``_BM?29@@P%X&1D`
M+1!-``/XC'TE&'$`+1!,``/X8WRX9Q``NH`0`"5@D`$M$$,`0`&CWP/X37PF
M$.P!+1AE``/X&'\F*$X`^G8-`'@1#0`M&'@``_BE?"403@`M&&4``_A"?"T8
M8@"X+QD`QB,"/+K(&0`#^&Y\)2BY`$@!H]\W[T(TN!`"``/XN'P#^)E])6"%
M`220.`,#^/!]^HX.`"1@C0$M&&(`>'D.`"T8<``E8)(!)7CQ`2U@@P$#^.]]
MN!\-`+IH#0`E&&T`+6"/`5`!L-\#^(U]`_AO?"4HHP`DD`\#>&$-`/J.#0`D
M**X`+8`"`BV`&0(E*+(`)<B1`2THL``#^#E_N&<.`+IP#@`E8(X!+2BY`%@!
ML-\#^*Y\`_B9?248;``DD/D!>"D.`/J.#@`D&&T`+8`"`BV`&`(E&'(`)<"Q
M`"T8<``#^!A_N"\-`+IH#0`E**T`+1AX`&`!L-\#^&U\`_BX?"5@A0$DD#@#
M>!D-`/J.#0`D8(X!+8`"`BV`#P(E8)(!)7AQ`"U@D`$#^.]]N!\.`+IP#@`E
M&&X`+6"/`6@!L-\#^(Y]`_AO?"4HHP`DD`\#>&$.`/J.#@`D**T`+8`"`BV`
M&0(E*+(`)<B1`2THL``#^#E_N&<-`+IH#0`E8(T!+2BY`'`!L-\#^*U\`_B9
M?248;``DD/D!>"D-`/J.#0`D&&X`+8`"`BV`&`(E&'(`)<"Q`"T8<``#^!A_
MN"\.`+IP#@`E**X`+1AX`'@!L-\#^&Y\`_BX?"5@A0$DD#@#>!D.`/J.#@`D
M8(T!+8`"`BV`#P(E8)(!)7AQ`"U@D`$#^.]]N!\-`+IH#0`E&&T`+6"/`8`!
ML-\#^(U]`_AO?"4HHP`DD`\#>&$-`/J.#0`D**X`+8`"`BV`&0(E*+(`)<B1
M`2THL``#^#E_N&<.`+IP#@`E8(X!+2BY`(@!L-\#^*Y\`_B9?248;``DD/D!
M>"D.`/J.#@`D&&T`+8`"`BV`&`(E&'(`)<"Q`"T8<``#^!A_N"\-`+IH#0`E
M**T`+1AX`)`!L-\#^&U\`_BX?"5@A0$DD#@#>!D-`/J.#0`D8(X!+8`"`BV`
M#P(E8)(!)7AQ`"U@D`$#^.]]N!\.`+IP#@`E&&X`+6"/`9@!L-\#^(Y]`_AO
M?"4HHP`DD`\#>&$.`/J.#@`D**T`+8`"`BV`&0(E*+(`)<B1`2THL``#^#E_
MN&<-`+IH#0`E8(T!+2BY`*`!L-\#^*U\`_B9?248;``DD/D!>"D-`/J.#0`D
M&&X`+8`"`BV`&`(E&'(`)<"Q`"T8<``#^!A_N"\.`+IP#@`E**X`+1AX`*@!
ML-\#^&Y\`_BX?"5@A0$DD#@#>!D.`/J.#@`D8(T!+8`"`BV`#P(E8)(!)7AQ
M`"U@D`$#^.]]N!\-`+IH#0`E&&T`+6"/`;`!L-\#^(U]`_AO?"4HHP`DD`\#
M>&$-`/J.#0`D**X`+8`"`BV`&0(E*+(`)<B1`2THL``#^#E_N&<.`+IP#@`E
M8(X!+2BY`+@!L-\#^*Y\`_B9?248;``DD/D!>"D.`/J.#@`D&&T`+8`"`BV`
M&`(E&'(`)<"Q`"T8<``#^!A_N"\-`+IH#0`E**T`+1AX`,`!L-\#^&U\`_BX
M?"5@A0$DD#@#>!D-`/J.#0`D8(X!+8`"`BV`#P(E8)(!)7AQ`"U@D`$#^.]]
MN!\.`+IP#@`E&&X`+6"/`<@!L-\#^(Y]`_AO?"4HHP`DD`\#>&$.`/J.#@`D
M**T`+8`"`BV`&0(E*+(`)<B1`2THL``#^#E_N&<-`+IH#0`E8(T!+2BY`-`!
ML-\#^*U\`_B9?248;``DD/D!>"D-`/J.#0`D&&X`+8`"`BV`&`(E&'(`)<"Q
M`"T8<``#^!A_N"\.`+IP#@`E**X`+1AX`-@!L-\#^'A\`_BN?"5@A0$DD"X#
M>!D8`/J.&``D8(T!+8`"`BV`#P(E8)(!)7AQ`"U@D`$#^.]]N!\-`+IH#0#@
M`;'?)1AM`"U@CP$#^(]]`_AM?"4HHP`D*+@`))C-`2V((@)X@0\`^I8/`"40
MLP`M*#D")<@2`BT010`#^#E_+<A9`+B'&`"Z*!@`,64"/"7`!0+K8$)DZ`&E
MWW@0`@`F&'@`+2BB`"88;``#^#!_+7"N``/X8WSZCA``+1AN`'AA$`"X=P\`
MNG@/`"5PSP$E8)$!)B@.`P/XC'TM8&P`)BBY`/`!N=\#^(]]+<@B`_J.#P!X
M&0\`+6@M`R48<0`#^*5\+2BM``/X8WRXSQ``NH`0`"THHP`ER#`#^`&CWP/X
MK7PF@-D!`_@1?RT88@`FP`P"^H8-`'AA#0`M&'$``_@8?R5@D`$M&'@``_B,
M?;C'#P"Z>`\`)7@/`RU@;````J/?`_B0?2;`+P,#^-%]+1AB`"9P!0/ZQA``
M>"D0`"T8<0`#^,Y])2BX`"T8;@`#^*5\N'<-`+IH#0`E:,T!+2AE``@"H]\#
M^+A\)G#M`?J.&``M&&(``_@Y?R9PS`%X81@`+1AY``/XSGTE8)$!+1AN``/X
MC'VX=Q``NH`0`"5PT`$M8&P`$`*CWP/XF7TF@*X!`_CQ?2T88@`F>`4"^H89
M`'@I&0`M&'$``_CO?24HL``M&&\``_BE?+A_&`"ZP!@`)7CX`2TH90`8`J/?
M`_BX?":`SP$#^+%]+1AB`"9H#`+ZAA@`>&$8`"T8<0`#^*U])6"0`2T8;0`#
M^(Q]N&\9`+K(&0`E:+D!+6!L`"`"H]\#^)E])H#M`0/XT7TM&&(`)G`%`OJ&
M&0!X*1D`+1AQ``/XSGTE*+``+1AN``/XI7RX=Q@`NL`8`"5PV`$M*&4`*`*C
MWP/XN'PF@*X!`_CQ?2T88@`F>`P"^H88`'AA&``M&'$``_CO?25@D`$M&&\`
M`_B,?;A_&0"ZR!D`)7CY`2U@;``P`J/?`_B9?2:`SP$#^+%]+1AB`"9H!0+Z
MAAD`>"D9`"T8<0`#^*U])2BP`"T8;0`#^*5\N&\8`+K`&``E:+@!+2AE`#@"
MH]\#^+A\)H#M`0/XT7TM&&(`)G`,`OJ&&`!X81@`+1AQ``/XSGTE8)`!+1AN
M``/XC'VX=QD`NL@9`"5PV0$M8&P`0`*CWP/XF7TF@*X!`_CQ?2T88@`F>`4"
M^H89`'@I&0`M&'$``_CO?24HL``M&&\``_BE?+A_&`"ZP!@`)7CX`2TH90!(
M`J/?`_BX?":`SP$#^+%]+1AB`"9H#`+ZAA@`>&$8`"T8<0`#^*U])6"0`2T8
M;0`#^(Q]N&\9`+K(&0`E:+D!+6!L`%`"H]\#^)E])H#M`0/XT7TM&&(`)G`%
M`OJ&&0!X*1D`+1AQ``/XSGTE*+``+1AN``/XI7RX=Q@`NL`8`"5PV`$M*&4`
M6`*CWP/XN'PF@*X!`_CQ?2T88@`F>`P"^H88`'AA&``M&'$``_CO?25@D`$M
M&&\``_B,?;A_&0"ZR!D`)7CY`2U@;`!@`J/?`_B9?2:`SP$#^+%]+1AB`"9H
M!0+ZAAD`>"D9`"T8<0`#^*U])2BP`"T8;0`#^*5\N&\8`+K`&``E:+@!+2AE
M`&@"H]\#^+A\)H#M`0/XT7TM&&(`)G`,`OJ&&`!X81@`+1AQ``/XSGTE8)`!
M+1AN``/XC'VX=QD`NL@9`"5PV0$M8&P`<`*CWP/XF7TF@*X!`_CQ?2T88@`F
M*`4">'D9`/J&&0`M&'$``_BE?"5X\`$M&&4``_CO?;@O&`"ZP!@`)2BX`"W`
M;P!X`J/?`_@/?R:`Q0$M&&(``_BQ?29H#`)X80\`^H8/``/XK7TM&'$`)6"0
M`2T8;0`#^(Q]N&\9`"T8;`"ZR!D``_AL?"5HN0&``J/?)LBM`"T08@`#^,Y]
M)L`X`W@9#`#ZS@P`+1!.`"48>0`#^`Y_`_AC?"T03@`M$$,``_A"?+@?#P`M
M$$L`NG@/``/X0GPE&&\```""_`/X8WP#^*)\`_BK?2T89P`M*&@!+3#,`"T0
M2@"(`JC?```GW0/XQGP#^&-\`_BE?`/X0GP(`(;\$`"#_!@`A?P)``<5(`""
M_+@"O]^P`KS?J`*SWZ`"LM^8`K'?D`*PWP@`X`/``KUGJ(*9WPGX(`,`````
ML/^]9T``O/\"`!P\+>"9`T@`O_\X`+;_,`"U_R@`M/\@`+/_&`"R_Q``L?\(
M`+#_20"`$%CYG&<H@8+?``!3W$4`8!(```````""@`,`0!`]``,D)`!#%"40
M@``ED`````!PWA,``!(EH*``):B``"6(8`(]`!8D,(&9WP`````E(``")3!`
M`@GX(`,E**`"!`!`%"T8$@(``&*`'`!6$``````(`#%F```PWO3_`!8P@9G?
M2`"_WR40``)``+S?.`"VWS``M=\H`+3?(`"SWQ@`LM\0`+'?"`"PWP@`X`-0
M`+UG`````#T`!B0!`$)D``!#@`,`8!`OD$0`_/]F%`$`0F36_P`0`)`2````
M```OB#,"^X@1````D:Y(`+_?`0!29BV`$@(E$``"0`"\WS@`MM\P`+7?*`"T
MWR``L]\8`++?$`"QWP@`L-\(`.`#4`"]9P````!(`+_?)8```"40``)``+S?
M.`"VWS``M=\H`+3?(`"SWQ@`LM\0`+'?"`"PWP@`X`-0`+UG`````+#_O6=`
M`+S_`@`</"W@F0/(]YQG,`"S_]B"D]\X`+3_*`"R_R``L?\8`+#_2`"__P``
M8MY0@)#?*(&2WR6(@``(`*+_!`"T9]@V$&8E*(`")<@``H;_$00E("`"$@!`
M$`0`HX\``$+>^!@#`"T00P`(`$/<]?]@$```0_P`````"`!"9`@`0]S]_V`4
M``!#_"4H@`(ER``"=?\1!"4@(`+P_T`4!`"CCP@`H]\``&+>"0!B%$@`O]]`
M`+S?.`"TWS``L]\H`++?(`"QWQ@`L-\(`.`#4`"]9ZB"F=\)^"`#````````
M``"@_[UG4`"\_P(`'#PMX)D#X/:<9R``LO_8@I+?&`"Q_Q``L/]8`+__2`"W
M_T``MO\X`+7_,`"T_R@`L_\E@*`````#@@``1=X]``(D)8B```@`I?\"`&(4
M^(&9WP$`$&8)^"`#)2```E"`F=\$`*5G)2`@`M@V.6=#_Q$$)9A``%D`0!`E
MH$``^(&9WPGX(`,E($``*Q!3`$<`0!`$`+:/*(&4W_BP%@```"*"@`!`$#T`
M`R1^`$,0/0`$)`0``!`E$"`"``````4`9!```````0!"9```0X#[_V`4````
M`"\040``$`(`,(*9WP(`9&8M(((`"?@@`P``D]XMF'8":`!`$```8OX$`*./
M``""WO@8`P`M$$,```!#W```(H(!`"1F"@!`$```8J`&```0/0`%)`````#_
M_X*``0!C9`,`0!```&*@^_]%%`$`A&0]``0D`0!B9```9*```````0`09O__
M`X(!`$)D_/]@%/__0Z`E$```"`"DWP``0]Y0`(,46`"_WU``O-](`+??0`"V
MWS@`M=\P`+3?*`"SWR``LM\8`+'?$`"PWP@`X`-@`+UG``````$`$&;__P*"
M`0"49NO_0!#__X*B`0`09O__`H(!`)1F]_]`%/__@J+E_P`0)1```"B!E-\`
M`)?>``#BWC``0!`E$.`"`P``$"4@````````)2!@``@`0F0``$7<`0"#)/O_
MH!0EJ&```P"$)/@@!``X@(+?@,-#C!4`8!0X@IG?,(*9WP$``R0)^"`#@,-#
MK!8`0!#X@IG?^+`5`"4PP`(E*.`""?@@`R4@0``E&$````""_@$`HF;X$`(`
M+1AB````8/R*_P`0!`"UKP`````E*(``)2#@`@GX(`/XL!4`)1A``//_0!0`
M`(+^M/\`$/__`B0`````C?\`$"40```0``0DVO\`$"6H``"H@IG?"?@@`P``
M``"P_KUG.`&\_P(`'#PMX)D#$/2<9P@!LO_8@I+?2`&__T`!OO\P`;?_*`&V
M_R`!M?\8`;3_$`&S_P`!L?_X`+#_``!"WN@`HO\$`(`0````````@H`2`$`4
M)8B``.@`H]\``$+>:`!B%$@!O]]``;[?.`&\WS`!M]\H`;;?(`&UWQ@!M-\0
M`;/?"`&RWP`!L=_X`+#?"`#@`U`!O6<`````^("9WPGX(`,`````Z_]`$"68
M0`!0@)7?4("4WU"`EM]89*)F4("7WTADE&8(`*+_$`"U9R`\UF9(@9G?"?@@
M`R4@8`(\`$`0`(&9WQ,`4&0H@YG?)2B``@GX(`,E(``"]O]`$$B!F=\H@YG?
M4&3E9@GX(`,E(``"\/]`$$B!F=_X@9G?"?@@`R4@(`+X@9G?)2```@GX(`,E
M\$``,(*9WRT0P@,`(`(`"?@@`P(`A"0(`*??\("9WR4@0``E2``")4`@`O__
M!B0!``4D"?@@`R7P0``@@9G?`P`$)"4PH`()^"`#)2C``___!"0%`$00,`"B
MCP!`!"0`\$(P%@!$$"7(P`*0@IG?"?@@`R4@P`/P@IG?"?@@`R4@P`-(@9G?
M"?@@`R4@8`+)_T`4$P!09`"!F=\`````"?@@`R4@8`+`@IG?"?@@`R4@(`*;
M_P`0``````````"!_Q$$)2#``^S_`!#P@IG?J(*9WPGX(`,```````````#_
MO6?P`+S_`@`</"W@F0/X\9QGX`"P_]B"D-_H`+'_^`"__Q"!F=\```+>)2B`
M`"6(@``E,*`#`P`$)-@`HO\)^"`#``````T`0!0@`*./`$`$)`#P8S`#`&00
M`*`$-`@`9!0`````>(&9WP(`!20)^"`#)2`@`@(``!`!`$(L)1```-@`I-\`
M``/>!@"#%/@`O]_P`+S?Z`"QW^``L-\(`.`#``&]9ZB"F=\)^"`#````````
M``"P[[UG0!"\_P(`'#PMX)D#0/&<9R@0L_\@$++_)9B``-B"DM]0@(3?,!"T
M_Q@0L?]($+__.!"U_Q`0L/]X@IG?"`"Q9P``0MXEH*``_P\&)"4H(`)@9(1D
M"!"B_PGX(`,``````!`"`#<`0!C__U`D$!"C9RT8<`"8@H3?^.]C@!\`8!0`
M`)6,)0``$JB!F=\E,``"+P`%)`GX(`,E("`"(`!`$!B!F=\)^"`#)2"@`EB!
MF=\E.``")3`@`B4H8`()^"`#)2!```@0H]\``$+>*0!B%$@0O]]`$+S?.!"U
MWS`0M-\H$+/?(!"RWQ@0L=\0$+#?"`#@`U`0O6<`````)8!``*B!F=\E,``"
M+P`%)`GX(`,E("`"X_]`%!B!F=\8@9G?"?@@`R4@H`)P@IG?)3"``B4H8`()
M^"`#)2!``.'_`!``````F(*"WQB!F=\``%6,"?@@`R4@H`)P@IG?)3"``B4H
M8`()^"`#)2!``-7_`!``````J(*9WPGX(`,``````````/#_O6<``+S_`@`<
M/"W@F0.X[YQGF(*"WP@`O_\8@9G?"?@@`P``1(Q8@(??4("%W\B"AM_0@9G?
M>*3G9'!DI60)^"`#)2!```@`O]\``+S?"`#@`Q``O6?@_[UG$`"\_P(`'#PM
MX)D#8.^<9P@`L/^8@I#?&`"__QB!F=\)^"`#```$CF"`F=_=_Q$$)2!``!B!
MF=\)^"`#```$CE"`B-]0@(7?`&@(98"!F=]H@(;?)4@``"4X``&09*5D"?@@
M`R4@0``8`+_?$`"\WP@`L-\(`.`#(`"]9Z#?O6=0(+S_`@`</"W@F0/@[IQG
M0""Q_]B"D=]8(+__2""R_S@@L/](@IG?```BWA@`L&<H(*+_"?@@`R`0LF=0
M@(G?4("'W_"`F=\E(``"J&0I925`0`"P9.=D`1`&)`GX(`,!``4D>(*9WR4@
M``(`$`8D"?@@`R4H0`(,`**O#`"PCQ@```8P@IG?"?@@`P$`!"8)`$`0)1A`
M`.""F=\,`*:/)2A``@GX(`,E($``+8!0`"480`````"B*""EWP``)-X*`*04
M)1!@`%@@O]]0(+S?2""RWT`@L=\X(+#?"`#@`V`@O6?T_P`0)1@``*B"F=\)
M^"`#```````````"``,\+1AY`.#M8V1P@'G<N_\`$`````"@[KUG2!&\_P(`
M'#PMX)D#R.V<9Q`1L?_8@H+?)8B``%"`F=]0@(3?6!&__R`1L_\($;#_4!&^
M_T`1M_\X$;;_,!&U_R@1M/\8$;+_"`"B_\!DA&0``$+<V#8Y9R68H``<`*5G
M^!"B_P']$00`````"(*9WR\`!20E("`""?@@`R6`0``:`$`0^(&9WU"`A-]0
M@)G?)2@@`E`Y.6>2_1$$T&2$9"40(`((`*/?^!"DWP``8]QR`(,46!&_WU`1
MOM]($;S?0!&WWS@1MM\P$;7?*!&TWR`1L]\8$;+?$!&QWP@1L-\(`.`#8!&]
M9P`````E("`""?@@`U"`DM]P@9G?)2!@`N!D168)^"`#`)@"`-[_0!`EN$``
M4("6WU"`E-\``.*"4("5WTADUF8Y`$`0Z&249@`````&```2*(.9WR4HX`()
M^"`#)2```BD`0!!P@9G?^(&9WPGX(`,E(.`"+P`#)``0`@`M(.("__^$@`8`
M@Q0O``4D__]")"T8X@+__V2`_/^%$```8*`!`&,F(1!B```00BB\_T`0\("9
MW_@`OF<E(,`#)5`@`B5(@`(E0.`"\&2G9@`0!B0)^"`#`0`%)""!F=\@`*9G
M)2C``PGX(`,#``0D!0!`%$``HH\`@`,T`/!",!4`0Q!X@9G?<(&9W^!D168)
M^"`#)2```*+_0!`EN$````#B@LK_0!0`````!@``$BB#F=\E*,`""?@@`R4@
M``+R_T`0<(&9WR6XP`+5_P`0`0`")``````!``4D"?@@`R4@P`/I_T`4<(&9
MWU"`A-]0@)G?)2C``U`Y.6<@_1$$T&2$9.B"F=\)^"`#)2#``XS_`!`(`*/?
MJ(*9WPGX(`,`````````````@X`'`&`0)1"````````!`(1D+P!E.```@X#\
M_V`4"A"%``@`X`,``````````.#_O6<0`+S_`@`</"W@F0,8`+__"`"Q_P``
ML/\F`(`0".N<9P``@H`C`$`0)8"``/B!F=\)^"`#`````/__0F0M$`("*Q@"
M`BX`8!`O``,D``!$@"(`@Q0`````!0``$"\`!"0```````!#@!P`9!0`````
M__]"9/O_`A8```````!#@"\``B1%`&(0Z(*9WU"`A-\)^"`#Z&2$9!@`O]\0
M`+S?"`"QWP``L-\(`.`#(`"]9P````!0@(3?Z(*9WPGX(`-(9(1D&`"_WQ``
MO-\(`+'?``"PWP@`X`,@`+UG!```$"\`!"0``$.`!P!D$`````#__T)D*Q@"
M`OK_8!0`````WO\"$@`````%```0+P`$)````````$.`!0!D%`````#__T)D
M*Q@"`OK_8!0`````+Q!0``(`0V0!$&,L#P!@$#B`D=^0@9G?)2@``H"S)&8`
M$`<D"?@@`P$`1F08`+_?@+,B9A``O-\(`+'?``"PWP@`X`,@`+UG`````!@`
MO]\0`+S?"`"QWP``L-\E$```"`#@`R``O6<`````4("$WPGX(`-(9(1DQ_\`
M$!@`O]\`````</^]9X``O/\"`!P\+>"9`U#IG&=(`+#_6("#WU"`D-]@`+/_
M4("$W]B"D]^(`+__:#@09E"D8F1X`+;_<`"U_V@`M/]8`++_4`"Q_U"D9]P(
M`$;<$`!%W!@`0]P``&C>(`!"E"7(``+X9(1D.`"H_Q``I_\8`*;_(`"E_R@`
MH_]!_!$$,`"BIU"`A-\ER``""&6$9#S\$010@)3?4("$WR7(``(0981D-_P1
M!%"`E=]0@(3?)<@``B!EA&0R_!$$4("6WR7(``(H981F+OP1!%"`D=]0@(3?
M)<@``CAEA&0I_!$$#`"R9R7(``(F_!$$P&2D9B7(``(C_!$$2&7$9B7(``(@
M_!$$6&4D9E"`A-\ER``"'/P1!&AEA&10@(3?)<@``M!DA&07_!$$4("0WU"`
MA-_8-A!F)2A``B7(``*M^Q$$>&6$9"\`0!!8921F4("1WU`Y,68ER"`"1/P1
M!"4H0`!0@(3?)2A``B7(``*A^Q$$D&6$9`4`0!!0@(3?)2A``"7((`(Y_!$$
MJ&6$9%"`A-\E*$`")<@``I;[$02X981D'`!`$"4H0``ER"`"+_P1!,!DI&90
M@(7?*&6$9B7((`(J_!$$\&6E9#@`H]\``&+>*0!B%(@`O]^``+S?>`"VWW``
MM=]H`+3?8`"SWU@`LM]0`+'?2`"PWP@`X`.0`+UG`````%"`D=_5_P`04#DQ
M9@````!0@(3?)2A``B7(``)T^Q$$R&6$9`8`0!`E*$``)<@@`@W\$01(9<1F
MWO\`$%"`A=]0@(7?,(&9WPH`!B3@9:5D"?@@`R$`I&?5_T`4*P"E9R7((`(`
M_!$$2&7$9M'_`!!0@(7?J(*9WPGX(`,`````T/^]9R``O/\"`!P\+>"9`\CF
MG&<8`+'_$`"P_SB`D=_8@I#?*`"__P``!-X0L"*.__\#)`@`I/\+`$,04("$
MWP@`I-\```/>&`"#%"@`O]\@`+S?&`"QWQ``L-\(`.`#,`"]9P````!0@)G?
M!`"E9]@V.6<^^Q$$2&6$9`@`0!````````!"@`4`0!``````,`!"."L0`@#I
M_P`0$+`BKB40``#F_P`0$+`BKJB"F=\)^"`#`````/#_O6<``+S_`@`</"W@
MF0,0YIQGH(*9WP@`O_\)^"`#``````B#F=\)^"`#)2!```4`0!`(`+_?``!"
MW```O-\(`.`#$`"]9P``O-\E$```"`#@`Q``O6>P_[UG0`"\_P(`'#PMX)D#
MN.6<9R@`LO\@`+'_4("2W]B"D=]0@)G?,`"S_T@`O_\X`+3_&`"P_P``(MXE
MF(``!`"E9_AE1&;8-CEG"`"B_P/[$00`````!@!`$%"`F=\E@$````!"@!,`
M0!0P@YG?4("9WR4H8`)0.3EGEOL1!/AE1&8(`*/?```BWBP`8A1(`+_?0`"\
MWS@`M-\P`+/?*`"RWR``L=\8`+#?"`#@`U``O6<`````)2A@`@GX(`,E(``"
M[_]`%/B!F=\)^"`#)2!@`OB!F=\E(``""?@@`R6@0``P@IG?+1""`@GX(`,"
M`$1D4(")WU"`A]_P@)G?)2!``"50``+@9"EE)4!@`O!DYV3__P8D`0`%)`GX
M(`,EH$``4("9WR4H@`)0.3EG:?L1!/AE1&;2_P`0`````*B"F=\)^"`#````
M```````0@+UGV'^\_P(`'#PMX)D#P'^U_[A_M/^H?[+_H'^Q_^A_O__@?[[_
MT'^W_\A_MO^P?[/_F'^P_VCDG&>P_;UG0`"G9U"`AM___P(\):B``*"!!#0M
M((<`='Y%9-B"@]\H`*;_+2B%`,!DQ&2@@08T+3#'`"T0P@`@`*/_F($&-```
M8]PM,,<```##_%"`@]]0@)3?&&9C9'A^0_Q0@(/?V#:49DAD8V2`?D/\4("#
MWU"`DM\@9F-DL'Y#_%"`@]]0@)'?*&9C9+A^0_Q0@(/?)<B``C!F8V3`?D/\
M4("#WZAE4F8X9F-DR'Y#_%"`@]\(9C%F0&9C9(A^0/RH?E+\T'Y`_)!^4?R8
M?D/\@/H1!*!^0/P$`$`0>("9WP``0X"'`6`4)2!``$O_$00`````20%`$"6`
M0`#X@9G?"?@@`R4@``(P@IG?>!`"``GX(`,!`$1D```#@A``8!`EB$``4("6
MWR68(`)09M9F````````")+P@)G?)2!@`B4XP`+__P8D`0`%)`GX(`,!`!!F
M```"@O;_0!0"`'-F__\6/$``HV>@@0(TJ'[09BT00P`M@%``4("3WZ"!`C1T
M?M9F+1!#`"4@0`(ML%8`!P``$#@^<V8`````"``09@````````3>;`"`$*"!
M`C0ER(`"1_H1!"4HP`+W_T`0)9!`````0H#T_T`0)<A@`AC\$00E($`"\O]`
M$`@`$&;X_Q!FZ(*9WPGX(`,E($`"6`!`$"6X0```````^(&9WR4@X`()^"`#
M4("3W_B!F=\E("`""?@@`R6`0``P@IG?+1`"`@`0`@`$!$(D)2!```GX(`,E
ML$``4("*WU"`A]_P@)G?)2!``"58(`)89DIEZ&1I9B5`X`)@9N=D__\&)`$`
M!20)^"`#)9!``,"!F=_``04D"?@@`R4@0`+__P,D!P!#%+"!F=\)^"`#````
M`!$``R0``$F,#@$C%0"#@M]``*-G__\1/*"!`C00@9G?+1!#`-A^)F8M,$8`
M)2A``@GX(`,#``0D1`!`$"6`0```@X+?4("&WT"!F=\``*?>``!$W"5`0`*P
M9L9D`0`%)`GX(`,EB```0`"C9YB!`C0M$$,```!$W"``HM\``$/<DP*#%"40
M(`)0`KUGZ'^_W^!_OM_8?[S?T'^WW\A_MM_`?[7?N'^TW[!_L]^H?[+?H'^Q
MWYA_L-\(`.`#\'^]9P````"@@0(T`````$``HV=0@);?__\3/"T00P`ED```
M+9A3`#@^UF;X$!(`+1!B`GA^4-R=_P`2);@``````H(0`$`0)<C``B4@``*E
M^Q$$`0!2)O7_0!#X$!(`Z(*9WPGX(`,E(``"D/]`%"6X0`#X$!(`+1!B`GA^
M4-SO_P`6`````(G_`!`EN```0`"C9Z"!`C0M$$,`+;A1`/A^XHX`0`,D`/!"
M,+;_0Q0`@X+?H(*9WPGX(`,(?_Z.L?]>%`"#@M_X?N*.P`$#)/\!0C"L_T,4
M`(."WS""F=\)^"`#)2#``D``I&>@@0,T+1AD`%"`A-]T?B5F+2AE``AGA&0E
MR(`"G_D1!"6(0`"S`$`0Z(*9WR4@0``)^"`#``"TWH"`F=\E*$``>OP1!"4@
M@`*J`$`0);!``/B!F=\)^"`#)2#``@"@`@`$`((J$P!`%(B`F=]0@(7?*(.9
MW_S_A&809Z5D"?@@`RT@Q`(+`$`4B("9WP0``B3C`8(2_/^")BT0P@+__T.`
M+P`")-X!8A``````B("9WP`````=_A$$``````@`0!10@(+?Z(&9WR4H```)
M^"`#)2#``HD`0!0P`*+_4(""WU"`A=]0@(3?\&6E9$AEA&10.5ED!_H1!"7P
M(`-(@IG?4("4WPGX(`/__Q4D4("'WP!HEV;P@)G?)5C@`B500`#H9&EF)4!`
M`C!GYV3__P8D`0`%)"4@(`()^"`#4("4WQ$`%B03```00&>49@GX(`,`````
M``!"C!0`5A1(@IG?"?@@`P$`$";P@)G?)5@``B500`#H9&EF)4!``B4X@`+_
M_P8D`0`%)"4@(`()^"`#``"W_\"!F=_``04D"?@@`R4@(`+I_U40L(&9W_""
MF=\)^"`#)2!``B@`HM\E*"`")<C``PGX(`/`9$1DD("9WQK^$00E("`".O\`
M$$``HV<`````__\3/$``HV>@@0(T+1!#`'1^=V8MN%<`H($"-"T00P`E("`"
M);```"V(4P`0`(`0,(*9WR4HX`(ER(`"'OD1!`$`UB8$`$`0````````0X`-
M`&`4Z(*9W_@0%@`M$"("D'Y$W/3_@!0E*.`",(*9WPT`!"0)^"`#4("0WQ!F
M$&:A_@`0)8A```GX(`,E($``D_Y`%"6`0`!``*1GH($"-"T01`#X&!8`+1!3
M`"T00P#>_P`0D'Y$W%"`AM]`@9G?``"GW@``1-PE0$`"<&;&9`$`!20)^"`#
M)8@```#_`!!``*-G`````)"`F=_:_1$$&`"B_Q@`HM_H@IG?"?@@`R4@0`#U
M_@`0)8A```````!6_P`0``"VWE""F=\E($```@`&).[_!20EJ$``"?@@`___
M$#Q``*-GH($"-"T00P#X?Q1F+:!4`!B#F=\&``8D)2B``@GX(`,E(*`"0`"C
M9Z"!`C0M$$,`+1!0`/A_0Y`$`&`40P`$)/E_0Y!-`60000`$)%""F=\P`*3?
M)3````GX(`,E*```0`"G9Z"!!C0M,,<`/0P"//__"#PM0,@`__\%/*"!!C0?
M+D)DV'ZI9#@1`@#X?Z4T74P#/"TPQP`MJ,4`?VYC9*"!!33X?@+]4(""WRTH
MIP!X&`,`YW<$)"VPJ0#`'T)D16<%/'@D!`#H?@/],A`#/`$CI62)JX1D=E1C
M9!@`HO\X`,)FV'X%_>!^!/WP?@/]`'\`_0A_`/U0?P"M)?```3@`HO](`+7_
M&(.9WS``I-\`@`8T"?@@`R4HH`(`N`(`7@#@&B6@X`(`?\/?^!`4`"T00P`#
M^$)\*QA#``(`8!`(?\7?`0"E9'H?%`!0?\2/+1AE``!_PO_C`(`0"'_#_T``
M%R0C$.0"*AA4``H0@P(E&$``)3!``#@`HM_@@IG?2`"EWRT@1``)^"`#)8!@
M`%!_PH\A$%``V_]7%%!_PJ\8`+G?)2#``@GX(`,CN)`"2`"BWRV`4`!``.(J
M*`!`%"6@``+`__<F@\GB?@$`5&2XH10`0`"B_RV@%`(`````!P`.:@\`#6H7
M``QJ'P`+:B<`!VHO``9J-P`%:C\``FH```YN"``-;A``#&X8``MN(``';B@`
M!FXP``5N.``";A!_SO\8`+G?)2#``AA_S?\@?\S_*'_+_S!_Q_\X?\;_0'_%
M_TA_PO\)^"`#0``09N/_%!9``*+?@($"`".X\`(@@IG?.`"DWR4PX`(E*(`"
M"?@@`T@`!R0P`*3?&(.9WP"`!C0E**`""?@@`U!_UZ\`N`(`I/_@'B6@X`((
M@9G?"?@@`S``I-]``*-GH($"-"T00P#__P<\+1A'``!_8MP`?V6,"']CC*"!
M!C1``*AGPRA"?"TPR`"@&`-\`0!$)`(<(P`M$,(`H"@%?`(L)0`M$.(`):!@
M`#D`ABB`_P,D);B@`(\`P!00?T.@H($"--A^]60M$$@`+:A5`,B!F=\X`+!F
M0``&)",PQ``E*```"?@@`RT@!`(8`+G?"?@@`R4@H`(X`*#^0`"@_D@`H/Y0
M`*#^6`"@_F``H/YH`*#^__\0/$``HV>@@0(T+1!#`-A^!&8M($0`H($"-"T0
M0P`8`+G?+:A0`$A_M*X)^"`#3'^WKD``J&>@@0<T+3CH`-A^IH[@?J6.Z'ZD
MCO!^HX[X?J*.R'\49BV@]`"@@0<T+3CH`*`P!GR@*`5\H"`$?*`8`WR@$`)\
M4("6WP(T)@`"+"4``B0D``(<(P`"%"(`+8#P`-M^J)*P?Z:NM'^EKKA_I*Z\
M?Z.NP'^BKK%_$&8H`)5F!```$%!FUF8````````(D@$`$&;P@)G?)2"``B4X
MP`+__P8D`0`%)`GX(`,"`)1F]O^T%O__`CQ``*1GH($#-"T89`#(?TID+5!J
M`$``K&>@@0,T4("+WU"`A]\M&&P`+1!B`/"`F=\`:&MEZ&1I9B5`0`(@9^=D
M__\&)`$`!20E("`"\']`H`GX(`,`````4(""W_""F=\E($`"4#E"9`GX(`,E
M\$``*`"BWR4H(`(ER,`#"?@@`\!D1&20@)G?DOP1!"4@(`*R_0`00`"C9P``
M``!``*-GH($"-"T00P#__P,\^']C-"[_`!`M@$,`"`"TWB'^@!+X@9G?"?@@
M`R4@@`($`$,L'OY@%(B`F=]0@(7?_/]"9"B#F=\89Z5D"?@@`RT@@@(4_@`0
M"K""`D``HV>@@0(T+1!#`/__`SPM$$,`$']"9,B!F=\X``8D(S#$`"4H```)
M^"`#+2!$`'O_`!#__Q`\^G]%D+/^I!10@IG?^W]$D+'^@Q0P`*3?_']$D$@`
M`R2L_H,4`````/U_0Y!%``(DJ/YB%#``L-]0@IG?)2```@(`!B0)^"`#QO\%
M)!B#F=\E*(`")2```@GX(`,I``8D4("+WU"`A]\`:&ME\("9WR50@`+H9&EF
M)4!``B!GYV3__P8D`0`%)*7_`!`E("`"J(*9WPGX(`,`````8/^]9X@`O/\"
M`!P\+>"9`\#6G&=0`+'_F(*1WY@`O_]8`++_2`"P_Y``OO^``+?_>`"V_W``
MM?]H`+3_8`"S_]B"@M\8@9G?```DCB@`HO\``$+<-`"R9R``LO\X`*+_"?@@
M`P```````"2.&(&9WPGX(`,E@$``4("&WU"`A-^X``.2V#;99"4H0`(H981D
MN0!#H#3W$008`+G_!`!`$#$``R0``$2`Z0"#$`````"8@)G?+OL1!``````8
M@9G?"?@@`P``)(Y0@(7?*(*9WPL`!R0!``8D6&>E9`GX(`,E($``V`!`$```
M```X@)/?$`!#W)##8HXH`'3<`@!"*#X`0!0``#Z.(``5/#B`E]\ED````0`0
M)``$M28,```0``06)``````0`(7<*(.9WPGX(`,E(``!+0!`%)##9(X!`!`F
M*A`$`BD`0!`!`%(F&(&9WPGX(`,E(,`#:(&9WR4H@`(E.```)3!``@GX(`,E
M($``O`!`$"4H0````$3<B,/CW@P`@HSX,!``+1AF`"0050```&C<X_]6$```
M/HX8@9G?)2#``P@`J/\)^"`#$`"E_Q``I=]H@IG?``"EW`(`!R0E,```"?@@
M`R4@0``(`*C?*(.9WR4@``$E*$``"?@@`P``/H[5_T`0D,-DCO__@B1V`%(0
M`@"$*!B!F=\)^"`#)2#``U"`A=\H@IG?`P`')`$`!B1@9Z5D"?@@`R4@0``1
M`$`0)8!``!B!F=\)^"`#```DCA```]Y0@(;?``!EW'""F=\E($``"?@@`VAG
MQF00``+>``!"W`P`0HR`!4)\D@!`%!B!F=\8@9G?"?@@`P``)(Y0@(7?*(*9
MWP,`!R0!``8D<&>E9`GX(`,E($``$@!`$"6`0`!0@(3?&`"YWR``I=\)^"`#
MT&2$9```)(XED$``<0!`$!B!F=\)^"`#`````!```]YP@IG?``!EW"4P0`()
M^"`#)2!``!B!F=\``"2."?@@`SB`DM\``"2.&(&9WPGX(`,E@$``4("%W^"!
MF=\!``8D>&>E9`GX(`,E($``4("&WW""F=\E(``"D&?&9`GX(`,E*$``&(&9
MWPGX(`,``"2.4("$WR``I=\8`+G?P&2$9`GX(`.Y`$"@)8!``"\`0!"8PT+^
MP(&9W\`!!20)^"`#)2```A$``R0$`$,0`0!#)`(`8RQ7`&`0.("#WR@`HM\X
M`*/?``!"W$\`8A28`+_?D`"^WX@`O-^``+??>`"VWW``M=]H`+3?8`"SWU@`
MLM]0`+'?2`"PWP@`X`.@`+UG`````(O_@!08@9G?`0`0)``````8@9G?)2#`
M`PGX(`,!`!`FT(*9WR4H@`()^"`#)2!``)##8HXJ$`("]?]`%```/HY[_P`0
M&(&9WSB`@M^@@)G?C?L1!(C#1-PE@$``S/]`%)C#0OY0@(3?V(&9WPGX(`.8
M9X1D`````&S_`!```#Z.`0!"@!G_0!"8@)G?%?\`$```````````D,-DCO__
M@B1B_U(4```^CM7_`!`"`(0H"?@@`P`````X@(/?$``"WHC#8]Q0@)G?``!E
MW/`^.6<W^!$$``!$W([_`!`8@9G?"?@@`P``)(X0``/>F(&9WP``9=P)^"`#
M)2!``&C_`!`8@9G?J(*9WPGX(`,`````4("$WXC#8]S8@9G?``!EW"4X0``E
M,``""?@@`\!GA&3@_[UG$`"\_P(`'#PMX)D#P-&<9ZB`F=\(`+'_``"P_Q@`
MO_^D^1$$)8B`````0X`&`&`0)8!```$`0F0O`&0X``!#@/S_8!0*@$0`B("9
MWZGZ$00`````#0!`$!@`O]\+`"`2````````(H((`$`04("%WS"!F=\$``8D
M6&:E9`GX(`,E(``"!@!`$!@`O]\0`+S?"`"QWP``L-\(`.`#(`"]9U"`F=\0
M`+S?``"PWR4@(`((`+'?(#PY9SSW`!`@`+UG````````````````\/^]9P``
MO/\"`!P\+>"9`_#0G&=(@(+?6(*9WP``1]P(`+__"?@@`P`````(`+_?``"\
MWP@`X`,0`+UG`````,#_O6<P`+S_`@`</"W@F0.PT)QG$`"R_P``L/_(@)+?
MT("0W]B`F=\OD%`"*`"U_R``M/\8`+/_.`"__P@`L?_[D!(`)9B``"6@H`#@
M[A$$):C```H`0!(EB```````````&=XE,*`")2B``B4@8`()^"`#`0`Q9OG_
M418(`!!F.`"_WS``O-\H`+7?(`"TWQ@`L]\0`++?"`"QWP``L-\(`.`#0`"]
M9P@`X`,`````$("9WR5XX`,)^"`#:P`89!"`F=\E>.`#"?@@`VH`&&00@)G?
M)7C@`PGX(`-H`!AD$("9WR5XX`,)^"`#9@`89!"`F=\E>.`#"?@@`V0`&&00
M@)G?)7C@`PGX(`-C`!AD$("9WR5XX`,)^"`#8@`89!"`F=\E>.`#"?@@`V$`
M&&00@)G?)7C@`PGX(`-?`!AD$("9WR5XX`,)^"`#70`89!"`F=\E>.`#"?@@
M`UP`&&00@)G?)7C@`PGX(`-;`!AD$("9WR5XX`,)^"`#6@`89!"`F=\E>.`#
M"?@@`UD`&&00@)G?)7C@`PGX(`-7`!AD$("9WR5XX`,)^"`#5@`89!"`F=\E
M>.`#"?@@`U0`&&00@)G?)7C@`PGX(`-3`!AD$("9WR5XX`,)^"`#4@`89!"`
MF=\E>.`#"?@@`U$`&&00@)G?)7C@`PGX(`-0`!AD$("9WR5XX`,)^"`#3P`8
M9!"`F=\E>.`#"?@@`TX`&&00@)G?)7C@`PGX(`--`!AD$("9WR5XX`,)^"`#
M3``89!"`F=\E>.`#"?@@`TL`&&00@)G?)7C@`PGX(`-*`!AD$("9WR5XX`,)
M^"`#20`89!"`F=\E>.`#"?@@`T<`&&00@)G?)7C@`PGX(`-&`!AD$("9WR5X
MX`,)^"`#10`89!"`F=\E>.`#"?@@`T0`&&00@)G?)7C@`PGX(`-#`!AD$("9
MWR5XX`,)^"`#0@`89!"`F=\E>.`#"?@@`T$`&&00@)G?)7C@`PGX(`-``!AD
M$("9WR5XX`,)^"`#/P`89!"`F=\E>.`#"?@@`SX`&&00@)G?)7C@`PGX(`,]
M`!AD$("9WR5XX`,)^"`#.P`89!"`F=\E>.`#"?@@`SH`&&00@)G?)7C@`PGX
M(`,Y`!AD$("9WR5XX`,)^"`#.``89!"`F=\E>.`#"?@@`S<`&&00@)G?)7C@
M`PGX(`,V`!AD$("9WR5XX`,)^"`#-0`89!"`F=\E>.`#"?@@`S0`&&00@)G?
M)7C@`PGX(`,S`!AD$("9WR5XX`,)^"`#,@`89!"`F=\E>.`#"?@@`S``&&00
M@)G?)7C@`PGX(`,O`!AD$("9WR5XX`,)^"`#+@`89!"`F=\E>.`#"?@@`RT`
M&&00@)G?)7C@`PGX(`,K`!AD$("9WR5XX`,)^"`#*0`89!"`F=\E>.`#"?@@
M`R@`&&00@)G?)7C@`PGX(`,G`!AD$("9WR5XX`,)^"`#)@`89!"`F=\E>.`#
M"?@@`R4`&&00@)G?)7C@`PGX(`,D`!AD$("9WR5XX`,)^"`#(P`89```````
M``````````````#P_[UG``"\_P(`'#PMX)D#"`"__R#,G&<(`+_?``"\WP@`
MX`,0`+UG```````````!``(``````"X`````````+BX````````E<R\E<P``
M`"]P<F]C+W-E;&8O97AE``!$>6YA3&]A9&5R.CIB;V]T7T1Y;F%,;V%D97(`
M`````$EN=&5R;F%L<SHZ4$%2.CI"3T]4`````&5X90``````+W!R;V,O)6DO
M)7,``````%!!4E]414U0``````````!005)?4%)/1TY!344`````.@``````
M```O`````````"5S)7,E<P``4$523#5,24(``````````%!%4DQ,24(`4$52
M3#5/4%0``````````%!%4DQ)3P``4$%27TE.251)04Q)6D5$`%!!4E]34$%7
M3D5$``````!005)?0TQ%04X`````````4$%27T1%0E5'`````````%!!4E]#
M04-(10````````!005)?1TQ/0D%,7T1%0E5'``````````!005)?1TQ/0D%,
M7U1-4$1)4@````````!005)?5$U01$E2````````4$%27T=,3T)!3%]414U0
M`%!!4E]'3$]"04Q?0TQ%04X``````````%!!4E]#3$5!3CT````````Q````
M`````$Q$7TQ)0E)!4EE?4$%42`!54T52`````%-94U1%30``+W1M<`````!4
M35!$25(``%1%35!$25(`5$5-4`````!435```````%5315).04U%````````
M```E,#)X`````'!A<BT`````)7,E<R5S)7,``````````"5S.B!C<F5A=&EO
M;B!O9B!P<FEV871E('-U8F1I<F5C=&]R>2`E<R!F86EL960@*&5R<FYO/25I
M*0H````````E<SH@<')I=F%T92!S=6)D:7)E8W1O<GD@)7,@:7,@=6YS869E
M("AP;&5A<V4@<F5M;W9E(&ET(&%N9"!R971R>2!Y;W5R(&]P97)A=&EO;BD*
M````````4$%42`````!P87)L`````"YP87(`````)7,E<V-A8VAE+25S)7,`
M`"5S)7-T96UP+25U)7,````E<R5S=&5M<"TE=2TE=25S``````````!!4D=6
M`````!@`````````<&5R;``````P`````````%!!4CHZ4&%C:V5R.CI615)3
M24].`````#$N,#0W````56YA8FQE('1O(&-R96%T92!C86-H92!D:7)E8W1O
M<GD``````````"5S.B!C<F5A=&EO;B!O9B!P<FEV871E(&-A8VAE('-U8F1I
M<F5C=&]R>2`E<R!F86EL960@*&5R<FYO/25I*0H``````````"UE````````
M+2T```````!E=F%L("=E>&5C("]U<W(O8FEN+W!E<FP@("U3("0P("1[,2LB
M)$`B?2<*:68@,#L@(R!N;W0@<G5N;FEN9R!U;F1E<B!S;VUE('-H96QL"G!A
M8VMA9V4@7U]P87)?<&P["FUY("@D<&%R7W1E;7`L("1P<F]G;F%M92P@0'1M
M<&9I;&4I.PI%3D0@>R!I9B`H)$5.5GM005)?0TQ%04Y]*2!["G)E<75I<F4@
M1FEL93HZ5&5M<#L*<F5Q=6ER92!&:6QE.CI"87-E;F%M93L*<F5Q=6ER92!&
M:6QE.CI3<&5C.PIM>2`D=&]P9&ER(#T@1FEL93HZ0F%S96YA;64Z.F1I<FYA
M;64H)'!A<E]T96UP*3L*;W5T<RAQ<7M296UO=FEN9R!F:6QE<R!I;B`B)'!A
M<E]T96UP(GTI.PI&:6QE.CI&:6YD.CIF:6YD9&5P=&@H<W5B('L@*"`M9"`I
M(#\@<FUD:7(@.B!U;FQI;FL@?2P@)'!A<E]T96UP*3L*<FUD:7(@)'!A<E]T
M96UP.PII9B`H+60@)'!A<E]T96UP("8F("1>3R!N92`G35-7:6XS,B<I('L*
M;7D@)'1M<"`](&YE=R!&:6QE.CI496UP*`I414U03$%412`]/B`G=&UP6%A8
M6%@G+`I$25(@/3X@1FEL93HZ0F%S96YA;64Z.F1I<FYA;64H)'1O<&1I<BDL
M"E-51D9)6"`]/B`G+F-M9"<L"E5.3$E.2R`]/B`P+`HI.PIP<FEN="`D=&UP
M("(C(2]B:6XO<V@*>#TQ.R!W:&EL92!;(%PD>"`M;'0@,3`@73L@9&\*<FT@
M+7)F("<D<&%R7W1E;7`G"FEF(%L@7"$@+60@)R1P87)?=&5M<"<@73L@=&AE
M;@IB<F5A:PIF:0IS;&5E<"`Q"G@]8&5X<'(@7"1X("L@,6`*9&]N90IR;2`G
M(B`N("1T;7`M/F9I;&5N86UE("X@(B<*(CL*8VAM;V0@,#<P,"PD=&UP+3YF
M:6QE;F%M93L*;7D@)&-M9"`]("1T;7`M/F9I;&5N86UE("X@)R`^+V1E=B]N
M=6QL(#(^)C$@)B<["F-L;W-E("1T;7`["G-Y<W1E;2@D8VUD*3L*;W5T<RAQ
M<2A3<&%W;F5D(&)A8VMG<F]U;F0@<')O8V5S<R!T;R!P97)F;W)M(&-L96%N
M=7`Z("D*+B`D=&UP+3YF:6QE;F%M92D["GT*?2!]"D)%1TE.('L*26YT97)N
M86QS.CI005(Z.D)/3U0H*2!I9B!D969I;F5D("9);G1E<FYA;',Z.E!!4CHZ
M0D]/5#L*979A;"!["E]P87)?:6YI=%]E;G8H*3L*;7D@)'%U:65T(#T@(21%
M3E9[4$%27T1%0E5'?3L*;7D@)4-O;F9I9R`]("@*<&%T:%]S97`@("`@/3X@
M*"1>3R`]?B`O7DU35VEN+R`_("<[)R`Z("<Z)RDL"E]E>&4@("`@("`@(#T^
M("@D7D\@/7X@+UXH/SI-4U=I;GQ/4S)\8WEG=VEN*2\@/R`G+F5X92<@.B`G
M)RDL"E]D96QI;2`@("`@(#T^("@D7D\@/7X@+UY-4U=I;GQ/4S(O(#\@)UQ<
M)R`Z("<O)RDL"BD["E]S971?<')O9VYA;64H*3L*7W-E=%]P87)?=&5M<"@I
M.PIM>2`H)'-T87)T7W!O<RP@)&1A=&%?<&]S*3L*>PIL;V-A;"`D4TE'>U]?
M5T%23E]??2`]('-U8B![?3L*;W!E;B!?1D@L("<\)RP@)'!R;V=N86UE(&]R
M(&QA<W0["F)I;FUO9&4H7T9(*3L*;7D@)&)U9CL*;7D@)'-I>F4@/2`M<R`D
M<')O9VYA;64["FUY("1O9F9S970@/2`U,3(["FUY("1I9'@@/2`M,3L*=VAI
M;&4@*#$I"GL*)&]F9G-E="`]("1S:7IE(&EF("1O9F9S970@/B`D<VEZ93L*
M<V5E:R!?1D@L("TD;V9F<V5T+"`R(&]R(&1I92!Q<5MS965K(&9A:6QE9"!O
M;B`B)'!R;V=N86UE(CH@)"%=.PIM>2`D;G)E860@/2!R96%D(%]&2"P@)&)U
M9BP@)&]F9G-E=#L*9&EE('%Q6W)E860@9F%I;&5D(&]N("(D<')O9VYA;64B
M.B`D(5T@=6YL97-S("1N<F5A9"`]/2`D;V9F<V5T.PHD:61X(#T@<FEN9&5X
M*"1B=68L(")<;E!!4BYP;5QN(BD["FQA<W0@:68@)&ED>"`^/2`P('Q\("1O
M9F9S970@/3T@)'-I>F4@?'P@)&]F9G-E="`^(#$R."`J(#$P,C0["B1O9F9S
M970@*CT@,CL*?0IL87-T('5N;&5S<R`D:61X(#X](#`["B1O9F9S970@+3T@
M)&ED>"`M(#0["G-E96L@7T9(+"`M)&]F9G-E="P@,CL*<F5A9"!?1D@L("1B
M=68L(#0["G-E96L@7T9(+"`M)&]F9G-E="`M('5N<&%C:R@B3B(L("1B=68I
M+"`R.PIR96%D(%]&2"P@)&)U9BP@-#L*)&1A=&%?<&]S(#T@*'1E;&P@7T9(
M*2`M(#0["FUY("5R97%U:7)E7VQI<W0["G=H:6QE("@D8G5F(&5Q(")&24Q%
M(BD@>PIR96%D(%]&2"P@)&)U9BP@-#L*<F5A9"!?1D@L("1B=68L('5N<&%C
M:R@B3B(L("1B=68I.PIM>2`D9G5L;&YA;64@/2`D8G5F.PIO=71S*'%Q*%5N
M<&%C:VEN9R!F:6QE("(D9G5L;&YA;64B+BXN*2D["FUY("1C<F,@/2`H("1F
M=6QL;F%M92`]?B!S?%XH6V$M9EQD77LX?2DO?'P@*2`_("0Q(#H@=6YD968[
M"FUY("@D8F%S96YA;64L("1E>'0I(#T@*"1B=68@/7X@;7PH/SHN*B\I/R@N
M*BDH7"XN*BE\*3L*<F5A9"!?1D@L("1B=68L(#0["G)E860@7T9(+"`D8G5F
M+"!U;G!A8VLH(DXB+"`D8G5F*3L*:68@*&1E9FEN960H)&5X="D@86YD("1E
M>'0@(7X@+UPN*#\Z<&U\<&Q\:7A\86PI)"]I*2!["FUY("1F:6QE;F%M92`]
M(%]T96UP9FEL92@B)&-R8R1E>'0B+"`D8G5F+"`P-S4U*3L*)%!!4CHZ2&5A
M=GDZ.D9U;&Q#86-H97LD9G5L;&YA;65](#T@)&9I;&5N86UE.PHD4$%2.CI(
M96%V>3HZ1G5L;$-A8VAE>R1F:6QE;F%M97T@/2`D9G5L;&YA;64["GT*96QS
M:68@*"`D9G5L;&YA;64@/7X@;7Q>+S]S:&QI8B]\(&%N9"!D969I;F5D("1%
M3E9[4$%27U1%35!]("D@>PIM>2`D9FEL96YA;64@/2!?=&5M<&9I;&4H(B1B
M87-E;F%M921E>'0B+"`D8G5F+"`P-S4U*3L*;W5T<R@B4TA,24(Z("1F:6QE
M;F%M95QN(BD["GT*96QS92!["B1R97%U:7)E7VQI<W1[)&9U;&QN86UE?2`]
M"B1005(Z.DAE879Y.CI-;V1U;&5#86-H97LD9G5L;&YA;65](#T@>PIB=68@
M/3X@)&)U9BP*8W)C(#T^("1C<F,L"FYA;64@/3X@)&9U;&QN86UE+`I].PI]
M"G)E860@7T9(+"`D8G5F+"`T.PI]"FQO8V%L($!)3D,@/2`H<W5B('L*;7D@
M*"1S96QF+"`D;6]D=6QE*2`]($!?.PIR971U<FX@:68@<F5F("1M;V1U;&4@
M;W(@(21M;V1U;&4["FUY("1F:6QE;F%M92`](&1E;&5T92`D<F5Q=6ER95]L
M:7-T>R1M;V1U;&5]('Q\(&1O('L*;7D@)&ME>3L*9F]R96%C:"`H:V5Y<R`E
M<F5Q=6ER95]L:7-T*2!["FYE>'0@=6YL97-S("]<421M;V1U;&5<120O.PHD
M:V5Y(#T@)%\[(&QA<W0["GT*9&5L971E("1R97%U:7)E7VQI<W1[)&ME>7T@
M:68@9&5F:6YE9"@D:V5Y*3L*?2!O<B!R971U<FX["B1)3D-[)&UO9'5L97T@
M/2`B+VQO861E<B\D9FEL96YA;64O)&UO9'5L92(["FEF("@D14Y6>U!!4E]#
M3$5!3GT@86YD(&1E9FEN960H)DE/.CI&:6QE.CIN97<I*2!["FUY("1F:"`]
M($E/.CI&:6QE+3YN97=?=&UP9FEL92!O<B!D:64@)"$["F)I;FUO9&4H)&9H
M*3L*<')I;G0@)&9H("1F:6QE;F%M92T^>V)U9GT["G-E96LH)&9H+"`P+"`P
M*3L*<F5T=7)N("1F:#L*?0IE;'-E('L*;7D@)&9I;&5N86UE(#T@7W1E;7!F
M:6QE*"(D9FEL96YA;64M/GMC<F-]+G!M(BP@)&9I;&5N86UE+3Y[8G5F?2D[
M"F]P96X@;7D@)&9H+"`G/"<L("1F:6QE;F%M92!O<B!D:64@(F-A;B=T(')E
M860@)&9I;&5N86UE.B`D(2(["F)I;FUO9&4H)&9H*3L*<F5T=7)N("1F:#L*
M?0ID:64@(D)O;W1S=')A<'!I;F<@9F%I;&5D.B!C86YN;W0@9FEN9"`D;6]D
M=6QE(5QN(CL*?2P@0$E.0RD["G)E<75I<F4@6%-,;V%D97(["G)E<75I<F4@
M4$%2.CI(96%V>3L*<F5Q=6ER92!#87)P.CI(96%V>3L*<F5Q=6ER92!%>'!O
M<G1E<CHZ2&5A=GD["E!!4CHZ2&5A=GDZ.E]I;FET7V1Y;F%L;V%D97(H*3L*
M<F5Q=6ER92!)3SHZ1FEL93L*=VAI;&4@*&UY("1F:6QE;F%M92`]("AS;W)T
M(&ME>7,@)7)E<75I<F5?;&ES="E;,%TI('L*=6YL97-S("@D24Y#>R1F:6QE
M;F%M97T@;W(@)&9I;&5N86UE(#U^("]"4T1004XO*2!["FEF("@D9FEL96YA
M;64@/7X@+UPN<&UC/R0O:2D@>PIR97%U:7)E("1F:6QE;F%M93L*?0IE;'-E
M('L*9&\@)&9I;&5N86UE('5N;&5S<R`D9FEL96YA;64@/7X@+W-I=&5C=7-T
M;VUI>F5<+G!L)"\["GT*?0ID96QE=&4@)')E<75I<F5?;&ES='LD9FEL96YA
M;65].PI]"FQA<W0@=6YL97-S("1B=68@97$@(E!+7#`P,UPP,#0B.PHD<W1A
M<G1?<&]S(#T@*'1E;&P@7T9(*2`M(#0["GT*;7D@0'!A<E]A<F=S.PIM>2`H
M)&]U="P@)&)U;F1L92P@)&QO9V9H+"`D8V%C:&5?;F%M92D["F1E;&5T92`D
M14Y6>U!!4E]!4%!?4D554T5].R`C('-A;FET:7IE("A2155312!M87D@8F4@
M82!S96-U<FET>2!P<F]B;&5M*0HD<75I970@/2`P('5N;&5S<R`D14Y6>U!!
M4E]$14)51WT["FEF("@A)'-T87)T7W!O<R!O<B`H)$%21U9;,%T@97$@)RTM
M<&%R+6]P=&EO;G,G("8F('-H:69T*2D@>PIM>2`E9&ES=%]C;60@/2!Q=R@*
M<"`@(&)L:6)?=&]?<&%R"FD@("!I;G-T86QL7W!A<@IU("`@=6YI;G-T86QL
M7W!A<@IS("`@<VEG;E]P87(*=B`@('9E<FEF>5]P87(**3L*:68@*$!!4D=6
M(&%N9"`D05)'5ELP72!E<2`G+2UR975S92<I('L*<VAI9G0@0$%21U8["B1%
M3E9[4$%27T%04%]2155317T@/2!S:&EF="!`05)'5CL*?0IE;'-E('L@(R!N
M;W)M86P@<&%R;"!B96AA=FEO=7(*;7D@0&%D9%]T;U]I;F,["G=H:6QE("A`
M05)'5BD@>PHD05)'5ELP72`]?B`O7BTH6T%)34]"3&)Q<&EU<U1V72DH+BHI
M+R!O<B!L87-T.PII9B`H)#$@97$@)TDG*2!["G!U<V@@0&%D9%]T;U]I;F,L
M("0R.PI]"F5L<VEF("@D,2!E<2`G32<I('L*979A;"`B=7-E("0R(CL*?0IE
M;'-I9B`H)#$@97$@)T$G*2!["G5N<VAI9G0@0'!A<E]A<F=S+"`D,CL*?0IE
M;'-I9B`H)#$@97$@)T\G*2!["B1O=70@/2`D,CL*?0IE;'-I9B`H)#$@97$@
M)V(G*2!["B1B=6YD;&4@/2`G<VET92<["GT*96QS:68@*"0Q(&5Q("=")RD@
M>PHD8G5N9&QE(#T@)V%L;"<["GT*96QS:68@*"0Q(&5Q("=Q)RD@>PHD<75I
M970@/2`Q.PI]"F5L<VEF("@D,2!E<2`G3"<I('L*;W!E;B`D;&]G9F@L("(^
M/B(L("0R(&]R(&1I92`B6%A8.B!#86YN;W0@;W!E;B!L;V<Z("0A(CL*?0IE
M;'-I9B`H)#$@97$@)U0G*2!["B1C86-H95]N86UE(#T@)#(["GT*<VAI9G0H
M0$%21U8I.PII9B`H;7D@)&-M9"`]("1D:7-T7V-M9'LD,7TI('L*9&5L971E
M("1%3E9[)U!!4E]414U0)WT["FEN:71?:6YC*"D["G)E<75I<F4@4$%2.CI$
M:7-T.PHF>R)005(Z.D1I<W0Z.B1C;60B?2@I('5N;&5S<R!`05)'5CL*)GLB
M4$%2.CI$:7-T.CHD8VUD(GTH)%\I(&9O<B!`05)'5CL*97AI=#L*?0I]"G5N
M<VAI9G0@0$E.0RP@0&%D9%]T;U]I;F,["GT*?0II9B`H)&]U="D@>PI["G)E
M<75I<F4@24\Z.D9I;&4["G)E<75I<F4@07)C:&EV93HZ6FEP.PI]"FUY("1P
M87(@/2!S:&EF="A`05)'5BD["FUY("1Z:7`["FEF("AD969I;F5D("1P87(I
M('L*07)C:&EV93HZ6FEP.CIS971#:'5N:U-I>F4H,3(X*C$P,C0I.PIO<&5N
M(&UY("1F:"P@)SPG+"`D<&%R(&]R(&1I92`B0V%N;F]T(&9I;F0@)R1P87(G
M.B`D(2(["F)I;FUO9&4H)&9H*3L*8FQE<W,H)&9H+"`G24\Z.D9I;&4G*3L*
M)'II<"`]($%R8VAI=F4Z.EII<"T^;F5W.PHH("1Z:7`M/G)E861&<F]M1FEL
M94AA;F1L92@D9F@L("1P87(I(#T]($%R8VAI=F4Z.EII<#HZ05I?3TLH*2`I
M"F]R(&1I92`B4F5A9"`G)'!A<B<@97)R;W(Z("0A(CL*?0IM>2`E96YV(#T@
M9&\@>PII9B`H)'II<"!A;F0@;7D@)&UE=&$@/2`D>FEP+3YC;VYT96YT<R@G
M345402YY;6PG*2D@>PHD;65T82`]?B!S+RXJ7G!A<CHD+R]M<SL*)&UE=&$@
M/7X@<R]>7%,N*B\O;7,["B1M971A(#U^("]>("`H6UXZ72LI.B`H+BLI)"]M
M9SL*?0I].PIL;V-A;"`D+R`](%PT.PII9B`H9&5F:6YE9"`D<&%R*2!["F]P
M96X@4$%2+"`G/"<L("1P87(@;W(@9&EE("(D(3H@)'!A<B(["F)I;FUO9&4H
M4$%2*3L*9&EE("(D<&%R(&ES(&YO="!A(%!!4B!F:6QE(B!U;FQE<W,@/%!!
M4CX@97$@(E!+7#`P,UPP,#0B.PI]"D-R96%T95!A=&@H)&]U="D@.PIM>2`D
M9F@@/2!)3SHZ1FEL92T^;F5W*`HD;W5T+`I)3SHZ1FEL93HZ3U]#4D5!5"@I
M('P@24\Z.D9I;&4Z.D]?5U)/3DQ9*"D@?"!)3SHZ1FEL93HZ3U]44E5.0R@I
M+`HP-S<W+`HI(&]R(&1I92`D(3L*8FEN;6]D92@D9F@I.PHD+R`]("AD969I
M;F5D("1D871A7W!O<RD@/R!<)&1A=&%?<&]S(#H@=6YD968["G-E96L@7T9(
M+"`P+"`P.PIM>2`D;&]A9&5R(#T@<V-A;&%R(#Q?1D@^.PII9B`H(21%3E9[
M4$%27U9%4D)!5$E-?2!A;F0@)&QO861E<B`]?B`O7B@_.B,A?%Q`<F5M*2\I
M('L*<F5Q=6ER92!005(Z.D9I;'1E<CHZ4&]D4W1R:7`["E!!4CHZ1FEL=&5R
M.CI0;V13=')I<"T^;F5W+3YA<'!L>2A<)&QO861E<BP@)#`I"GT*9F]R96%C
M:"!M>2`D:V5Y("AS;W)T(&ME>7,@)65N=BD@>PIM>2`D=F%L(#T@)&5N=GLD
M:V5Y?2!O<B!N97AT.PHD=F%L(#T@979A;"`D=F%L(&EF("1V86P@/7X@+UY;
M)R)=+SL*;7D@)&UA9VEC(#T@(E]?14Y67U!!4E\B("X@=6,H)&ME>2D@+B`B
M7U\B.PIM>2`D<V5T(#T@(E!!4E\B("X@=6,H)&ME>2D@+B`B/21V86PB.PHD
M;&]A9&5R(#U^('-[)&UA9VEC*"`K*7U["B1M86=I8R`N("1S970@+B`H)R`G
M('@@*&QE;F=T:"@D,2D@+2!L96YG=&@H)'-E="DI*0I]96<["GT*)&9H+3YP
M<FEN="@D;&]A9&5R*3L*)"\@/2!U;F1E9CL*:68@*"1B=6YD;&4I('L*<F5Q
M=6ER92!005(Z.DAE879Y.PI005(Z.DAE879Y.CI?:6YI=%]D>6YA;&]A9&5R
M*"D["FEN:71?:6YC*"D["G)E<75I<F5?;6]D=6QE<R@I.PIM>2!`:6YC(#T@
M9W)E<"![("$O0E-$4$%.+R!]"F=R97`@>PHH)&)U;F1L92!N92`G<VET92<I
M(&]R"B@D7R!N92`D0V]N9FEG.CI#;VYF:6=[87)C:&QI8F5X<'T@86YD"B1?
M(&YE("1#;VYF:6<Z.D-O;F9I9WMP<FEV;&EB97AP?2D["GT@0$E.0SL*;7D@
M)69I;&5S.PHD9FEL97-[)%]]*RL@9F]R($!$>6YA3&]A9&5R.CID;%]S:&%R
M961?;V)J96-T<RP@=F%L=65S("5)3D,["FUY("1L:6)?97AT(#T@)$-O;F9I
M9SHZ0V]N9FEG>VQI8E]E>'1].PIM>2`E=W)I='1E;CL*9F]R96%C:"`H<V]R
M="!K97ES("5F:6QE<RD@>PIM>2`H)&YA;64L("1F:6QE*3L*9F]R96%C:"!M
M>2`D9&ER("A`:6YC*2!["FEF("@D;F%M92`]("1005(Z.DAE879Y.CI&=6QL
M0V%C:&5[)%]]*2!["B1F:6QE(#T@)%\["FQA<W0["GT*96QS:68@*"]>*%Q1
M)&1I<EQ%7"\H+BI;7D-C72DI7%HO:2D@>PHH)&9I;&4L("1N86UE*2`]("@D
M,2P@)#(I.PIL87-T.PI]"F5L<VEF("AM(5XO;&]A9&5R+UM>+UTK+R@N*EM>
M0V-=*5Q:(2D@>PII9B`H;7D@)')E9B`]("1005(Z.DAE879Y.CI-;V1U;&5#
M86-H97LD,7TI('L**"1F:6QE+"`D;F%M92D@/2`H)')E9BP@)#$I.PIL87-T
M.PI]"F5L<VEF("@M9B`B)&1I<B\D,2(I('L**"1F:6QE+"`D;F%M92D@/2`H
M(B1D:7(O)#$B+"`D,2D["FQA<W0["GT*?0I]"FYE>'0@=6YL97-S(&1E9FEN
M960@)&YA;64@86YD(&YO="`D=W)I='1E;GLD;F%M97TK*SL*;F5X="!I9B`A
M<F5F*"1F:6QE*2!A;F0@)&9I;&4@/7X@+UPN7%$D;&EB7V5X=%Q%)"\["F]U
M=',H(&IO:6X@(B(L"G%Q*%!A8VMI;F<@(BDL(')E9B`D9FEL92`_("1F:6QE
M+3Y[;F%M97T@.B`D9FEL92P*<7$H(BXN+BD**3L*;7D@)&-O;G1E;G0["FEF
M("AR968H)&9I;&4I*2!["B1C;VYT96YT(#T@)&9I;&4M/GMB=69].PI]"F5L
M<V4@>PIO<&5N($9)3$4L("<\)RP@)&9I;&4@;W(@9&EE(")#86XG="!O<&5N
M("1F:6QE.B`D(2(["F)I;FUO9&4H1DE,12D["B1C;VYT96YT(#T@/$9)3$4^
M.PIC;&]S92!&24Q%.PI005(Z.D9I;'1E<CHZ4&]D4W1R:7`M/FYE=RT^87!P
M;'DH7"1C;VYT96YT+"`D9FEL92D*:68@(21%3E9[4$%27U9%4D)!5$E-?2!A
M;F0@)&YA;64@/7X@+UPN*#\Z<&U\:7A\86PI)"]I.PI005(Z.D9I;'1E<CHZ
M4&%T8VA#;VYT96YT+3YN97<M/F%P<&QY*%PD8V]N=&5N="P@)&9I;&4L("1N
M86UE*3L*?0IO=71S*'%Q*%=R:71T96X@87,@(B1N86UE(BDI.PHD9F@M/G!R
M:6YT*")&24Q%(BD["B1F:"T^<')I;G0H<&%C:R@G3B<L(&QE;F=T:"@D;F%M
M92D@*R`Y*2D["B1F:"T^<')I;G0H<W!R:6YT9B@*(B4P.'@O)7,B+"!!<F-H
M:79E.CI::7`Z.F-O;7!U=&5#4D,S,B@D8V]N=&5N="DL("1N86UE"BDI.PHD
M9F@M/G!R:6YT*'!A8VLH)TXG+"!L96YG=&@H)&-O;G1E;G0I*2D["B1F:"T^
M<')I;G0H)&-O;G1E;G0I.PI]"GT*)'II<"T^=W)I=&54;T9I;&5(86YD;&4H
M)&9H*2!I9B`D>FEP.PHD8V%C:&5?;F%M92`]('-U8G-T<B`D8V%C:&5?;F%M
M92P@,"P@-#`["FEF("@A)&-A8VAE7VYA;64@86YD(&UY("1M=&EM92`]("AS
M=&%T*"1O=70I*5LY72D@>PIM>2`D8W1X(#T@979A;"![(')E<75I<F4@1&EG
M97-T.CI32$$[($1I9V5S=#HZ4TA!+3YN97<H,2D@?0I\?"!E=F%L('L@<F5Q
M=6ER92!$:6=E<W0Z.E-(03$[($1I9V5S=#HZ4TA!,2T^;F5W('T*?'P@979A
M;"![(')E<75I<F4@1&EG97-T.CI-1#4[($1I9V5S=#HZ340U+3YN97<@?3L*
M;7D@)'-H85]V97)S:6]N(#T@979A;"![("1$:6=E<W0Z.E-(03HZ5D524TE/
M3B!]('Q\(#`["FEF("@D<VAA7W9E<G-I;VX@97$@)S4N,S@G(&]R("1S:&%?
M=F5R<VEO;B!E<2`G-2XS.2<I('L*)&-T>"T^861D9FEL92@D;W5T+"`B8B(I
M(&EF("@D8W1X*3L*?0IE;'-E('L*:68@*"1C='@@86YD(&]P96XH;7D@)&9H
M+"`B/"1O=70B*2D@>PIB:6YM;V1E*"1F:"D["B1C='@M/F%D9&9I;&4H)&9H
M*3L*8VQO<V4H)&9H*3L*?0I]"B1C86-H95]N86UE(#T@)&-T>"`_("1C='@M
M/FAE>&1I9V5S="`Z("1M=&EM93L*?0HD8V%C:&5?;F%M92`N/2`B7#`B('@@
M*#0Q("T@;&5N9W1H("1C86-H95]N86UE*3L*)&-A8VAE7VYA;64@+CT@(D-!
M0TA%(CL*)&9H+3YP<FEN="@D8V%C:&5?;F%M92D["B1F:"T^<')I;G0H<&%C
M:R@G3B<L("1F:"T^=&5L;"`M(&QE;F=T:"@D;&]A9&5R*2DI.PHD9F@M/G!R
M:6YT*")<;E!!4BYP;5QN(BD["B1F:"T^8VQO<V4["F-H;6]D(#`W-34L("1O
M=70["F5X:70["GT*>PIL87-T('5N;&5S<R!D969I;F5D("1S=&%R=%]P;W,[
M"E]F:7A?<')O9VYA;64H*3L*<F5Q=6ER92!005(["E!!4CHZ2&5A=GDZ.E]I
M;FET7V1Y;F%L;V%D97(H*3L*>PIR97%U:7)E($9I;&4Z.D9I;F0["G)E<75I
M<F4@07)C:&EV93HZ6FEP.PI]"FUY("1Z:7`@/2!!<F-H:79E.CI::7`M/FYE
M=SL*;7D@)&9H(#T@24\Z.D9I;&4M/FYE=SL*)&9H+3YF9&]P96XH9FEL96YO
M*%]&2"DL("=R)RD@;W(@9&EE("(D(3H@)$`B.PHD>FEP+3YR96%D1G)O;49I
M;&5(86YD;&4H)&9H+"`D<')O9VYA;64I(#T]($%R8VAI=F4Z.EII<#HZ05I?
M3TLH*2!O<B!D:64@(B0A.B`D0"(["G!U<V@@0%!!4CHZ3&EB0V%C:&4L("1Z
M:7`["B1005(Z.DQI8D-A8VAE>R1P<F]G;F%M97T@/2`D>FEP.PHD<75I970@
M/2`A)$5.5GM005)?1$5"54=].PIO=71S*'%Q*%PD14Y6>U!!4E]414U0?2`]
M("(D14Y6>U!!4E]414U0?2(I*3L*:68@*&1E9FEN960@)$5.5GM005)?5$5-
M4'TI('L@(R!S:&]U;&0@8F4@<V5T(&%T('1H:7,@<&]I;G0A"F9O<F5A8V@@
M;7D@)&UE;6)E<B`H("1Z:7`M/FUE;6)E<G,@*2!["FYE>'0@:68@)&UE;6)E
M<BT^:7-$:7)E8W1O<GD["FUY("1M96UB97)?;F%M92`]("1M96UB97(M/F9I
M;&5.86UE.PIN97AT('5N;&5S<R`D;65M8F5R7VYA;64@/7X@;7L*7@HO/W-H
M;&EB+PHH/SHD0V]N9FEG.CI#;VYF:6=[=F5R<VEO;GTO*3\**#\Z)$-O;F9I
M9SHZ0V]N9FEG>V%R8VAN86UE?2\I/PHH6UXO72LI"B0*?7@["FUY("1E>'1R
M86-T7VYA;64@/2`D,3L*;7D@)&1E<W1?;F%M92`]($9I;&4Z.E-P96,M/F-A
M=&9I;&4H)$5.5GM005)?5$5-4'TL("1E>'1R86-T7VYA;64I.PII9B`H+68@
M)&1E<W1?;F%M92`F)B`M<R!?(#T]("1M96UB97(M/G5N8V]M<')E<W-E9%-I
M>F4H*2D@>PIO=71S*'%Q*%-K:7!P:6YG("(D;65M8F5R7VYA;64B('-I;F-E
M(&ET(&%L<F5A9'D@97AI<W1S(&%T("(D9&5S=%]N86UE(BDI.PI](&5L<V4@
M>PIO=71S*'%Q*$5X=')A8W1I;F<@(B1M96UB97)?;F%M92(@=&\@(B1D97-T
M7VYA;64B*2D["B1M96UB97(M/F5X=')A8W14;T9I;&5.86UE9"@D9&5S=%]N
M86UE*3L*8VAM;V0H,#4U-2P@)&1E<W1?;F%M92D@:68@)%Y/(&5Q(")H<'5X
M(CL*?0I]"GT*?0IU;FQE<W,@*"1005(Z.DQI8D-A8VAE>R1P<F]G;F%M97TI
M('L*9&EE(#P\("(N(B!U;FQE<W,@0$%21U8["E5S86=E.B`D,"!;("U!;&EB
M+G!A<B!=(%L@+4ED:7(@72!;("U-;6]D=6QE(%T@6R!S<F,N<&%R(%T@6R!P
M<F]G<F%M+G!L(%T*)#`@6R`M0GPM8B!=(%LM3V]U=&9I;&5=('-R8RYP87(*
M+@HD14Y6>U!!4E]04D]'3D%-17T@/2`D<')O9VYA;64@/2`D,"`]('-H:69T
M*$!!4D=6*3L*?0IS=6(@0W)E871E4&%T:"!["FUY("@D;F%M92D@/2!`7SL*
M<F5Q=6ER92!&:6QE.CI"87-E;F%M93L*;7D@*"1B87-E;F%M92P@)'!A=&@L
M("1E>'0I(#T@1FEL93HZ0F%S96YA;64Z.F9I;&5P87)S92@D;F%M92P@*"=<
M+BXJ)RDI.PIR97%U:7)E($9I;&4Z.E!A=&@["D9I;&4Z.E!A=&@Z.FUK<&%T
M:"@D<&%T:"D@=6YL97-S*"UE("1P871H*3L@(R!M:W!A=&@@9&EE<R!W:71H
M(&5R<F]R"GT*<W5B(')E<75I<F5?;6]D=6QE<R!["G)E<75I<F4@;&EB.PIR
M97%U:7)E($1Y;F%,;V%D97(["G)E<75I<F4@:6YT96=E<CL*<F5Q=6ER92!S
M=')I8W0["G)E<75I<F4@=V%R;FEN9W,["G)E<75I<F4@=F%R<SL*<F5Q=6ER
M92!#87)P.PIR97%U:7)E($-A<G`Z.DAE879Y.PIR97%U:7)E($5R<FYO.PIR
M97%U:7)E($5X<&]R=&5R.CI(96%V>3L*<F5Q=6ER92!%>'!O<G1E<CL*<F5Q
M=6ER92!&8VYT;#L*<F5Q=6ER92!&:6QE.CI496UP.PIR97%U:7)E($9I;&4Z
M.E-P96,["G)E<75I<F4@6%-,;V%D97(["G)E<75I<F4@0V]N9FEG.PIR97%U
M:7)E($E/.CI(86YD;&4["G)E<75I<F4@24\Z.D9I;&4["G)E<75I<F4@0V]M
M<')E<W,Z.EIL:6(["G)E<75I<F4@07)C:&EV93HZ6FEP.PIR97%U:7)E(%!!
M4CL*<F5Q=6ER92!005(Z.DAE879Y.PIR97%U:7)E(%!!4CHZ1&ES=#L*<F5Q
M=6ER92!005(Z.D9I;'1E<CHZ4&]D4W1R:7`["G)E<75I<F4@4$%2.CI&:6QT
M97(Z.E!A=&-H0V]N=&5N=#L*<F5Q=6ER92!A='1R:6)U=&5S.PIE=F%L('L@
M<F5Q=6ER92!#=V0@?3L*979A;"![(')E<75I<F4@5VEN,S(@?3L*979A;"![
M(')E<75I<F4@4V-A;&%R.CI5=&EL('T["F5V86P@>R!R97%U:7)E($%R8VAI
M=F4Z.E5N>FEP.CI"=7)S="!].PIE=F%L('L@<F5Q=6ER92!4:64Z.DAA<V@Z
M.DYA;65D0V%P='5R92!].PIE=F%L('L@<F5Q=6ER92!097)L24\[(')E<75I
M<F4@4&5R;$E/.CIS8V%L87(@?3L*979A;"![(')E<75I<F4@=71F."!].PI]
M"G-U8B!?<V5T7W!A<E]T96UP('L*:68@*&1E9FEN960@)$5.5GM005)?5$5-
M4'T@86YD("1%3E9[4$%27U1%35!](#U^("\H+BLI+RD@>PHD<&%R7W1E;7`@
M/2`D,3L*<F5T=7)N.PI]"F9O<F5A8V@@;7D@)'!A=&@@*`HH;6%P("1%3E9[
M)%]]+"!Q=R@@4$%27U1-4$1)4B!435!$25(@5$5-4$1)4B!414U0(%1-4"`I
M*2P*<7<H($,Z7%Q414U0("]T;7`@+B`I"BD@>PIN97AT('5N;&5S<R!D969I
M;F5D("1P871H(&%N9"`M9"`D<&%T:"!A;F0@+7<@)'!A=&@["FUY("1U<V5R
M;F%M93L*;7D@)'!W=6ED.PIE=F%L('LH)'!W=6ED*2`](&=E='!W=6ED*"0^
M*2!I9B!D969I;F5D("0^.WT["FEF("@@9&5F:6YE9"@F5VEN,S(Z.DQO9VEN
M3F%M92D@*2!["B1U<V5R;F%M92`]("97:6XS,CHZ3&]G:6Y.86UE.PI]"F5L
M<VEF("AD969I;F5D("1P=W5I9"D@>PHD=7-E<FYA;64@/2`D<'=U:60["GT*
M96QS92!["B1U<V5R;F%M92`]("1%3E9[55-%4DY!345]('Q\("1%3E9[55-%
M4GT@?'P@)U-94U1%32<["GT*)'5S97)N86UE(#U^(',O7%<O7R]G.PIM>2`D
M<W1M<&1I<B`]("(D<&%T:"1#;VYF:6=[7V1E;&EM?7!A<BTB+G5N<&%C:R@B
M2"HB+"`D=7-E<FYA;64I.PIM:V1I<B`D<W1M<&1I<BP@,#<U-3L*:68@*"$D
M14Y6>U!!4E]#3$5!3GT@86YD(&UY("1M=&EM92`]("AS=&%T*"1P<F]G;F%M
M92DI6SE=*2!["F]P96X@*&UY("1F:"P@(CPB+B`D<')O9VYA;64I.PIS965K
M("1F:"P@+3$X+"`R.PIS>7-R96%D("1F:"P@;7D@)&)U9BP@-CL*:68@*"1B
M=68@97$@(EPP0T%#2$4B*2!["G-E96L@)&9H+"`M-3@L(#(["G-Y<W)E860@
M)&9H+"`D8G5F+"`T,3L*)&)U9B`]?B!S+UPP+R]G.PHD<W1M<&1I<B`N/2`B
M)$-O;F9I9WM?9&5L:6U]8V%C:&4M(B`N("1B=68["GT*96QS92!["FUY("1C
M='@@/2!E=F%L('L@<F5Q=6ER92!$:6=E<W0Z.E-(03L@1&EG97-T.CI32$$M
M/FYE=R@Q*2!]"GQ\(&5V86P@>R!R97%U:7)E($1I9V5S=#HZ4TA!,3L@1&EG
M97-T.CI32$$Q+3YN97<@?0I\?"!E=F%L('L@<F5Q=6ER92!$:6=E<W0Z.DU$
M-3L@1&EG97-T.CI-1#4M/FYE=R!].PIM>2`D<VAA7W9E<G-I;VX@/2!E=F%L
M('L@)$1I9V5S=#HZ4TA!.CI615)324].('T@?'P@,#L*:68@*"1S:&%?=F5R
M<VEO;B!E<2`G-2XS."<@;W(@)'-H85]V97)S:6]N(&5Q("<U+C,Y)RD@>PHD
M8W1X+3YA9&1F:6QE*"1P<F]G;F%M92P@(F(B*2!I9B`H)&-T>"D["GT*96QS
M92!["FEF("@D8W1X(&%N9"!O<&5N*&UY("1F:"P@(CPD<')O9VYA;64B*2D@
M>PIB:6YM;V1E*"1F:"D["B1C='@M/F%D9&9I;&4H)&9H*3L*8VQO<V4H)&9H
M*3L*?0I]"B1S=&UP9&ER("X]("(D0V]N9FEG>U]D96QI;7UC86-H92TB("X@
M*"`D8W1X(#\@)&-T>"T^:&5X9&EG97-T(#H@)&UT:6UE("D["GT*8VQO<V4H
M)&9H*3L*?0IE;'-E('L*)$5.5GM005)?0TQ%04Y](#T@,3L*)'-T;7!D:7(@
M+CT@(B1#;VYF:6=[7V1E;&EM?71E;7`M)"0B.PI]"B1%3E9[4$%27U1%35!]
M(#T@)'-T;7!D:7(["FUK9&ER("1S=&UP9&ER+"`P-S4U.PIL87-T.PI]"B1P
M87)?=&5M<"`]("0Q(&EF("1%3E9[4$%27U1%35!](&%N9"`D14Y6>U!!4E]4
M14U0?2`]?B`O*"XK*2\["GT*<W5B(%]T96UP9FEL92!["FUY("@D;F%M92P@
M)&-O;G1E;G1S+"`D;6]D92D@/2!`7SL*;7D@)&9U;&QN86UE(#T@(B1P87)?
M=&5M<"\D;F%M92(["G5N;&5S<R`H+64@)&9U;&QN86UE*2!["FUY("1T96UP
M;F%M92`]("(D9G5L;&YA;64N)"0B.PIO<&5N(&UY("1F:"P@)SXG+"`D=&5M
M<&YA;64@;W(@9&EE(")C86XG="!W<FET92`D=&5M<&YA;64Z("0A(CL*8FEN
M;6]D92`D9F@["G!R:6YT("1F:"`D8V]N=&5N=',["F-L;W-E("1F:#L*8VAM
M;V0@)&UO9&4L("1T96UP;F%M92!I9B!D969I;F5D("1M;V1E.PIR96YA;64H
M)'1E;7!N86UE+"`D9G5L;&YA;64I(&]R('5N;&EN:R@D=&5M<&YA;64I.PI]
M"G)E='5R;B`D9G5L;&YA;64["GT*<W5B(%]S971?<')O9VYA;64@>PII9B`H
M9&5F:6YE9"`D14Y6>U!!4E]04D]'3D%-17T@86YD("1%3E9[4$%27U!23T=.
M04U%?2`]?B`O*"XK*2\I('L*)'!R;V=N86UE(#T@)#$["GT*)'!R;V=N86UE
M('Q\/2`D,#L*:68@*"1%3E9[4$%27U1%35!](&%N9"!I;F1E>"@D<')O9VYA
M;64L("1%3E9[4$%27U1%35!]*2`^/2`P*2!["B1P<F]G;F%M92`]('-U8G-T
M<B@D<')O9VYA;64L(')I;F1E>"@D<')O9VYA;64L("1#;VYF:6=[7V1E;&EM
M?2D@*R`Q*3L*?0II9B`H(21%3E9[4$%27U!23T=.04U%?2!O<B!I;F1E>"@D
M<')O9VYA;64L("1#;VYF:6=[7V1E;&EM?2D@/CT@,"D@>PII9B`H;W!E;B!M
M>2`D9F@L("<\)RP@)'!R;V=N86UE*2!["G)E='5R;B!I9B`M<R`D9F@["GT*
M:68@*"US("(D<')O9VYA;64D0V]N9FEG>U]E>&5](BD@>PHD<')O9VYA;64@
M+CT@)$-O;F9I9WM?97AE?3L*<F5T=7)N.PI]"GT*9F]R96%C:"!M>2`D9&ER
M("AS<&QI="`O7%$D0V]N9FEG>W!A=&A?<V5P?5Q%+RP@)$5.5GM0051(?2D@
M>PIN97AT(&EF(&5X:7-T<R`D14Y6>U!!4E]414U0?2!A;F0@)&1I<B!E<2`D
M14Y6>U!!4E]414U0?3L*)&1I<B`]?B!S+UQ1)$-O;F9I9WM?9&5L:6U]7$4D
M+R\["B@H)'!R;V=N86UE(#T@(B1D:7(D0V]N9FEG>U]D96QI;7TD<')O9VYA
M;64D0V]N9FEG>U]E>&5](BDL(&QA<W0I"FEF("US("(D9&ER)$-O;F9I9WM?
M9&5L:6U])'!R;V=N86UE)$-O;F9I9WM?97AE?2(["B@H)'!R;V=N86UE(#T@
M(B1D:7(D0V]N9FEG>U]D96QI;7TD<')O9VYA;64B*2P@;&%S="D*:68@+7,@
M(B1D:7(D0V]N9FEG>U]D96QI;7TD<')O9VYA;64B.PI]"GT*<W5B(%]F:7A?
M<')O9VYA;64@>PHD,"`]("1P<F]G;F%M92!\?#T@)$5.5GM005)?4%)/1TY!
M345].PII9B`H:6YD97@H)'!R;V=N86UE+"`D0V]N9FEG>U]D96QI;7TI(#P@
M,"D@>PHD<')O9VYA;64@/2`B+B1#;VYF:6=[7V1E;&EM?21P<F]G;F%M92([
M"GT*;7D@)'!W9"`]("AD969I;F5D("9#=V0Z.F=E=&-W9"D@/R!#=V0Z.F=E
M=&-W9"@I"CH@*"AD969I;F5D("97:6XS,CHZ1V5T0W=D*2`_(%=I;C,R.CI'
M971#=V0H*2`Z(&!P=V1@*3L*8VAO;7`H)'!W9"D["B1P<F]G;F%M92`]?B!S
M+UXH/SU<+EPN/UQ1)$-O;F9I9WM?9&5L:6U]7$4I+R1P=V0D0V]N9FEG>U]D
M96QI;7TO.PHD14Y6>U!!4E]04D]'3D%-17T@/2`D<')O9VYA;64["GT*<W5B
M(%]P87)?:6YI=%]E;G8@>PII9B`H("1%3E9[4$%27TE.251)04Q)6D5$?2LK
M(#T](#$@*2!["G)E='5R;CL*?2!E;'-E('L*)$5.5GM005)?24Y)5$E!3$E:
M141](#T@,CL*?0IF;W(@*'%W*"!34$%73D5$(%1%35`@0TQ%04X@1$5"54<@
M0T%#2$4@4%)/1TY!344@05)'0R!!4D=67S`@*2`I('L*9&5L971E("1%3E9[
M)U!!4E\G+B1??3L*?0IF;W(@*'%W+R!435!$25(@5$5-4"!#3$5!3B!$14)5
M1R`O*2!["B1%3E9[)U!!4E\G+B1??2`]("1%3E9[)U!!4E]'3$]"04Q?)RXD
M7WT@:68@97AI<W1S("1%3E9[)U!!4E]'3$]"04Q?)RXD7WT["GT*;7D@)'!A
M<E]C;&5A;B`](")?7T5.5E]005)?0TQ%04Y?7R`@("`@("`@("`@("`@("([
M"FEF("@D14Y6>U!!4E]414U0?2D@>PID96QE=&4@)$5.5GM005)?0TQ%04Y]
M.PI]"F5L<VEF("@A97AI<W1S("1%3E9[4$%27T=,3T)!3%]#3$5!3GTI('L*
M;7D@)'9A;'5E(#T@<W5B<W1R*"1P87)?8VQE86XL(#$R("L@;&5N9W1H*")#
M3$5!3B(I*3L*)$5.5GM005)?0TQ%04Y](#T@)#$@:68@)'9A;'5E(#U^("]>
M4$%27T-,14%./2A<4RLI+SL*?0I]"G-U8B!O=71S('L*<F5T=7)N(&EF("1Q
M=6EE=#L*:68@*"1L;V=F:"D@>PIP<FEN="`D;&]G9F@@(D!?7&XB.PI]"F5L
M<V4@>PIP<FEN="`B0%]<;B(["GT*?0IS=6(@:6YI=%]I;F,@>PIR97%U:7)E
M($-O;F9I9SL*<'5S:"!`24Y#+"!G<F5P(&1E9FEN960L(&UA<"`D0V]N9FEG
M.CI#;VYF:6=[)%]]+"!Q=R@*87)C:&QI8F5X<"!P<FEV;&EB97AP('-I=&5A
M<F-H97AP('-I=&5L:6)E>'`*=F5N9&]R87)C:&5X<"!V96YD;W)L:6)E>'`*
M*3L*?0IP86-K86=E(&UA:6X["G)E<75I<F4@4$%2.PIU;G-H:69T($!)3D,L
M(%PF4$%2.CIF:6YD7W!A<CL*4$%2+3YI;7!O<G0H0'!A<E]A<F=S*3L*9&EE
M('%Q*'!A<BYP;#H@0V%N)W0@;W!E;B!P97)L('-C<FEP="`B)'!R;V=N86UE
M(CH@3F\@<W5C:"!F:6QE(&]R(&1I<F5C=&]R>5QN*0IU;FQE<W,@+64@)'!R
M;V=N86UE.PID;R`D<')O9VYA;64["D-/4D4Z.F5X:70H)#$I(&EF("@D0"`]
M?B]>7U1+7T58251?7"@H7&0K*5PI+RD["F1I92`D0"!I9B`D0#L*?3L*)#HZ
M7U]%4E)/4B`]("1`(&EF("1`.PI]"D-/4D4Z.F5X:70H)#$I(&EF("@D.CI?
M7T524D]2(#U^+UY?5$M?15A)5%]<*"A<9"LI7"DO*3L*9&EE("0Z.E]?15)2
M3U(@:68@)#HZ7U]%4E)/4CL*,3L*7U]%3D1?7PH``````%]?14Y67U!!4E]#
M3$5!3E]?("`@("`@("`@("`@("`@``````````!P97)L>'-I+F,`````````
M```````````O;&EB-C0O;&0N<V\N,0````````0````0`````0```$=.50``
M`````P````(`````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````````````````````````)@?````
M````*!\`````````````````````````````_____P```````````````!AH
M````````````````````````````````````````````````````````````
M@)`;````````@%\````````H8````````````@``````.+`!``````!HLP$`
M```````````````````!``````!X0````````'!9````````4$$````````@
M2@```````&A"````````:$D```````!X2@```````.!&````````R$L`````
M```H10```````$!?````````(+`!``````!P7@```````/BO`0``````\*\!
M``````!0&P````````````````````````````#P8P```````.!C````````
MT&,```````#`8P```````+!C````````H&,```````"08P``````````````
M````@&,``````````````````'!C````````8&,```````!08P```````$!C
M```````````````````P8P```````"!C````````$&,`````````8P``````
M`/!B````````X&(```````#08@```````,!B````````L&(```````"@8@``
M````````````````D&(```````"`8@```````'!B````````8&(```````!0
M8@```````$!B````````,&(````````@8@```````!!B`````````&(`````
M``#P80``````````````````X&$```````#080```````,!A````````L&$`
M``````"@80```````)!A````````@&$```````!P80```````&!A````````
M4&$```````!`80```````#!A```````````````````@80```````!!A````
M````````````````80```````/!@````````X&````````#08````````,!@
M``````````````````"P8```````````````````H&````````"08```````
M`(!@````````<&```````````````````&!@``````````````````!08```
M````````````````0&`````````P8````````&BS`0``````1T-#.B`H1&5B
M:6%N(#@N,BXP+3DI(#@N,BXP`$=#0SH@*$1E8FEA;B`W+C,N,"TR.2D@-RXS
M+C``````P!\`````#Y#X____``````````#``@``'0```!\```#8-@````!_
MD/C___\``````````%`````=````'P```&@X`````!^0^/___P``````````
M4````!T````?````4#D`````_Y#X____``````````!@````'0```!\````@
M/`````#_T/C___\``````````%`!```=````'P```#@^``````.0^/___P``
M``````````$``!T````?````\#X`````/Y#X____``````````!0$```'0``
M`!\```!X0```````D/C___\``````````!`````=````'P```-!```````&0
M^/___P``````````(````!T````?````4$$`````!Y#X____``````````!@
M(```'0```!\```!00@`````````````````````````````=````'P```&A"
M`````/_0^/___P``````````8!$``!T````?````^$0`````````````````
M````````````'0```!\````H10`````#D/C___\``````````"`````=````
M'P```.!&`````'^0^/___P``````````D````!T````?````:$D``````Y#X
M____```````````P````'0```!\````@2@``````D/C___\``````````!``
M```=````'P```'A*`````!^0^/___P``````````4````!T````?````R$L`
M````_]#X____``````````!`@@``'0```!\```!P60````#_T/C___\`````
M`````*`````=````'P```'!>``````.0^/___P``````````(````!T````?
M````D!L`````/Y#X____``````````!P````'0```!\```!`7P``````D/C_
M__\``````````!`````=````'P```(!?`````#^0^/___P``````````0```
M`!T````?````*&``````````````````````````````'0```!\```!!#P``
M`&=N=0`!!P````0!`"YS:'-T<G1A8@`N34E04RYA8FEF;&%G<P`N34E04RYO
M<'1I;VYS`"YN;W1E+F=N=2YB=6EL9"UI9``N9'EN86UI8P`N:&%S:``N9'EN
M<WEM`"YD>6YS='(`+F=N=2YV97)S:6]N`"YG;G4N=F5R<VEO;E]R`"YR96PN
M9'EN`"YI;FET`"YT97AT`"Y-25!3+G-T=6)S`"YF:6YI`"YR;V1A=&$`+FEN
M=&5R<``N96A?9G)A;64`+FYO=&4N04))+71A9P`N:6YI=%]A<G)A>0`N9FEN
M:5]A<G)A>0`N9&%T80`N<FQD7VUA<``N9V]T`"YS9&%T80`N8G-S`"YC;VUM
M96YT`"YP9'(`+F=N=2YA='1R:6)U=&5S````````````````````````````
M````````````````````````````````````````````````````````````
M"P```"H``'`"`````````'`"````````<`(````````8````````````````
M````"``````````8`````````!H````-``!P`@``"`````"(`@```````(@"
M````````D`$```````````````````@``````````0`````````H````!P``
M``(`````````&`0````````8!````````"0````````````````````$````
M````````````````.P````8````"`````````$`$````````0`0```````"@
M`@````````<`````````"``````````0`````````$0````%`````@``````
M``#@!@```````.`&````````/`,````````&``````````@`````````!```
M``````!*````"P````(`````````(`H````````@"@```````"`*````````
M!P````(````(`````````!@`````````4@````,````"`````````$`4````
M````0!0````````R!0```````````````````0```````````````````%H`
M``#___]O`@````````!R&0```````'(9````````V``````````&````````
M``(``````````@````````!G````_O__;P(`````````4!H```````!0&@``
M`````+``````````!P````,````(````````````````````=@````D````"
M```````````;`````````!L```````!0``````````8`````````"```````
M```0`````````'\````!````!@````````!0&P```````%`;````````0```
M``````````````````0```````````````````"%`````0````8`````````
MD!L```````"0&P```````*!$```````````````````0````````````````
M````BP````$````&`````````#!@````````,&````````#@`P``````````
M````````"````````````````````)<````!````!@`````````09```````
M`!!D````````*`````````````````````0```````````````````"=````
M`0````(`````````0&0```````!`9````````%!````````````````````0
M````````````````````I0````$````"`````````)"D````````D*0`````
M```/`````````````````````0```````````````````*T````!`````@``
M``````"@I````````*"D````````!`````````````````````0`````````
M``````````"W````!P````(`````````I*0```````"DI````````"``````
M```````````````$````````````````````Q0````X````#`````````/"O
M`0``````\*\````````(````````````````````"``````````(````````
M`-$````/`````P````````#XKP$``````/BO````````"```````````````
M``````@`````````"`````````#=`````0````,``````````+`!````````
ML````````#`````````````````````0````````````````````XP````$`
M```#`````````#"P`0``````,+`````````(````````````````````"```
M`````````````````.P````!`````P``$`````!`L`$``````$"P````````
M*`,``````````````````!``````````"`````````#Q`````0````,``!``
M````:+,!``````!HLP````````@````````````````````(````````````
M````````^`````@````#`````````'"S`0``````<+,```````!`$```````
M````````````$````````````````````/T````!````,```````````````
M`````'"S````````.0````````````````````$``````````0`````````&
M`0```0````````````````````````"LLP```````"`#````````````````
M```$````````````````````"P$``/7__V\`````````````````````S+8`
M```````0`````````````````````0````````````````````$````#````
M`````````````````````-RV````````&P$```````````````````$`````
+````````````````
